@@ -451,7 +451,7 @@ bool MyMoneyStatementReader::import(const MyMoneyStatement& s, QStringList& mess
 
 
         // we ask the user only if we have some transactions to process
-        if (!m_userAbort && s.m_listTransactions.count() > 0)
+        if (!m_userAbort && !s.m_listTransactions.isEmpty())
             m_userAbort = ! selectOrCreateAccount(Select, d->m_account);
     }
 
@@ -487,7 +487,7 @@ bool MyMoneyStatementReader::import(const MyMoneyStatement& s, QStringList& mess
 
     if (!d->m_account.name().isEmpty())
         messages += i18n("Importing statement for account %1", d->m_account.name());
-    else if (s.m_listTransactions.count() == 0)
+    else if (s.m_listTransactions.isEmpty())
         messages += i18n("Importing statement without transactions");
 
     qDebug("Importing statement for '%s'", qPrintable(d->m_account.name()));
@@ -1595,7 +1595,7 @@ void MyMoneyStatementReader::handleMatchingOfScheduledTransaction(MyMoneySchedul
     if (askUserToEnterScheduleForMatching(schedule, importedSplit, importedTransaction)) {
         const auto origDueDate = schedule.nextDueDate();
 
-        MyMoneyTransaction t = MyMoneyFile::instance()->scheduledTransaction(schedule);
+        MyMoneyTransaction t = MyMoneyFile::instance()->scheduledTransaction(schedule, AccountBalanceCache());
 
         // since the previous call returns a transaction with a
         // cleared id and date, the date will be set based on the
