@@ -12,16 +12,17 @@
 #ifndef MYMONEYSTATEMENTREADER_H
 #define MYMONEYSTATEMENTREADER_H
 
+#include "qcontainerfwd.h"
 #include <QObject>
 #include <QString>
 #include <QStringList>
 
+#include "mymoneyenums.h"
 #include "mymoneystatement.h"
 #include "transactionmatchfinder.h"
 
 class MyMoneyFileTransaction;
 class TransactionMatcher;
-class QStringList;
 class MyMoneyAccount;
 class MyMoneyInstitution;
 
@@ -60,7 +61,8 @@ public:
       * @param create flag if this feature should be turned on (@p true)
       *               or turned off (@p false)
       */
-    void setAutoCreatePayee(bool create);
+    void setPayeeCreationMode(eMyMoney::Account::PayeeCreation creationMode);
+
     void setAskPayeeCategory(bool ask);
 
     const MyMoneyAccount& account() const;
@@ -79,20 +81,12 @@ public:
       * UI to handle account matching, payee creation, and someday
       * payee and transaction matching.
       */
-    static QStringList importStatement(const QString& url, bool silent = false, void(*callback)(int, int, const QString&) = nullptr);
-    static QStringList importStatement(const MyMoneyStatement& s, bool silent = false, void(*callback)(int, int, const QString&) = nullptr);
+    static QStringList importStatement(const QString& url, bool silent = false);
+    static QStringList importStatement(const MyMoneyStatement& s, bool silent = false);
     static void clearResultMessages();
     static QStringList resultMessages();
 
 private:
-    /**
-      * This method is used to update the progress information. It
-      * checks if an appropriate function is known and calls it.
-      *
-      * For a parameter description see KMyMoneyView::progressCallback().
-      */
-    void signalProgress(int current, int total, const QString& = "");
-
     void processTransactionEntry(const MyMoneyStatement::Transaction& t_in);
     void processSecurityEntry(const MyMoneyStatement::Security& s_in);
 
@@ -127,24 +121,20 @@ private:
     Private* const d;
     QStringList             m_dontAskAgain;
     bool                    m_userAbort;
-    bool                    m_autoCreatePayee;
+    eMyMoney::Account::PayeeCreation m_payeeCreationMode;
     bool                    m_askPayeeCategory;
     MyMoneyFileTransaction* m_ft;
 
-    void (*m_progressCallback)(int, int, const QString&);
+    void handleMatchingOfExistingTransaction(MyMoneyTransaction matchedTransaction,
+                                             MyMoneySplit matchedSplit,
+                                             MyMoneyTransaction& importedTransaction,
+                                             const MyMoneySplit& importedSplit,
+                                             const TransactionMatchFinder::MatchResult& matchResult);
 
-    void handleMatchingOfExistingTransaction(TransactionMatcher & matcher,
-            MyMoneyTransaction matchedTransaction,
-            MyMoneySplit matchedSplit,
-            MyMoneyTransaction & importedTransaction,
-            const MyMoneySplit & importedSplit,
-            const TransactionMatchFinder::MatchResult & matchResult);
-
-    void handleMatchingOfScheduledTransaction(TransactionMatcher & matcher,
-            MyMoneySchedule matchedSchedule,
-            MyMoneySplit matchedSplit,
-            const MyMoneyTransaction & importedTransaction,
-            const MyMoneySplit & importedSplit);
+    void handleMatchingOfScheduledTransaction(MyMoneySchedule matchedSchedule,
+                                              MyMoneySplit matchedSplit,
+                                              const MyMoneyTransaction& importedTransaction,
+                                              const MyMoneySplit& importedSplit);
     void addTransaction(MyMoneyTransaction & transaction);
 
     /** Asks the user whether to enter a schedule transaction to match it with imported one
