@@ -87,6 +87,10 @@ public:
         ui->setupUi(q);
 
         ui->m_messageWidget->hide();
+        ui->m_maxCreditEarlyEdit->setAllowEmpty();
+        ui->m_maxCreditAbsoluteEdit->setAllowEmpty();
+        ui->m_minBalanceEarlyEdit->setAllowEmpty();
+        ui->m_minBalanceAbsoluteEdit->setAllowEmpty();
 
         auto file = MyMoneyFile::instance();
 
@@ -174,17 +178,14 @@ public:
         ui->typeCombo->setEnabled(true);
 
         // load the price mode combo
-        ui->m_priceMode->insertItem(i18nc("default price mode", "(default)"), 0);
-        ui->m_priceMode->insertItem(i18n("Price per share"), 1);
-        ui->m_priceMode->insertItem(i18n("Total for all shares"), 2);
+        ui->m_priceMode->insertItem(i18nc("default price mode", "(default)"), (int)eMyMoney::Invest::PriceMode::Price);
+        ui->m_priceMode->insertItem(i18n("Price per share"), (int)eMyMoney::Invest::PriceMode::PricePerShare);
+        ui->m_priceMode->insertItem(i18n("Total for all shares"), (int)eMyMoney::Invest::PriceMode::PricePerTransaction);
 
-        int priceMode = 0;
         if (m_account.accountType() == Account::Type::Investment) {
             ui->m_priceMode->setEnabled(true);
-            if (!m_account.value("priceMode").isEmpty())
-                priceMode = m_account.value("priceMode").toInt();
         }
-        ui->m_priceMode->setCurrentItem(priceMode);
+        ui->m_priceMode->setCurrentItem((int)m_account.priceMode());
 
         bool haveMinBalance = false;
         bool haveMaxCredit = false;
@@ -639,12 +640,12 @@ public:
             }
         }
 
-        QPointer<KNewAccountDlg> dialog = new KNewAccountDlg(account, false, isCategory, 0, title);
+        QPointer<KNewAccountDlg> dialog = new KNewAccountDlg(account, false, isCategory, nullptr, title);
 
         dialog->setOpeningBalanceShown(false);
         dialog->setOpeningDateShown(false);
 
-        if (dialog->exec() == QDialog::Accepted && dialog != 0) {
+        if (dialog->exec() == QDialog::Accepted && dialog != nullptr) {
             MyMoneyAccount parentAccount, brokerageAccount;
             account = dialog->account();
             parentAccount = dialog->parentAccount();
@@ -942,15 +943,7 @@ void KNewAccountDlg::okClicked()
     }
 
     // update the price mode
-    switch (d->ui->m_priceMode->currentItem()) {
-    case 0:
-        d->m_account.deletePair("priceMode");
-        break;
-    case 1:
-    case 2:
-        d->m_account.setValue("priceMode", QString("%1").arg(d->ui->m_priceMode->currentItem()));
-        break;
-    }
+    d->m_account.setPriceMode(d->ui->m_priceMode->currentData().value<eMyMoney::Invest::PriceMode>());
 
     accept();
 }
