@@ -1,7 +1,6 @@
 /*
     SPDX-FileCopyrightText: 2017 Łukasz Wojniłowicz <lukasz.wojnilowicz@gmail.com>
     SPDX-FileCopyrightText: 2020 Dawid Wróbel <me@dawidwrobel.com>
-
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
@@ -21,83 +20,81 @@ class QIcon;
 
 namespace Icons {
 
-enum class IconSet { Common, Oxygen, Tango, Breeze };
-
 // clang-format off
-enum class Icon { OpenDatabase, Merge, Reconcile, Split, Tip, PerformanceTest,
+enum class Icon { OpenDatabase, Link, Unlink, Reconcile, Split, Tip, PerformanceTest,
                   Calculator,
                   UserProperties, DocumentProperties,
                   ZoomIn, ZoomOut,
-                  Pause, SeekForward,
-                  SkipForward,
+                  Pause, SeekForward, SeekBackward,
+                  SkipForward, SkipBackward,
                   HideReconciled, HideCategories,
-                  ShowReconciledBalances,
                   Home, Institution, Institutions,
                   Accounts,
                   Schedule, Tags,
-                  Payees,
-                  Investment, Investments, Reports,
-                  Budget, Forecast,
+                  Payee, Payees,
+                  Investment, InvestmentClosed, Investments, Reports,
+                  Budget, Budgets, Forecast,
                   OnlineJobOutbox, Filter,
-                  Loan, Stock,
-                  Checking,
-                  Savings,
-                  LoanAsset, CreditCard,
-                  Cash, Equity,
+                  Loan, LoanClosed, Security, SecurityClosed,
+                  Checking, CheckingClosed,
+                  Savings, SavingsClosed,
+                  AssetLoan, AssetLoanClosed,CreditCard, CreditCardClosed,
+                  Cash, CashClosed, Equity,
                   Income, Expense,
-                  Asset, Liability,
-                  UpcomingEvents, CalendarDay,
-                  Ledger, BankAccount,
+                  Asset, AssetClosed, Liability, LiabilityClosed,
+                  ScheduleOverdue, ScheduleOnTime, CalendarDay,
+                  Ledger, Ledgers, BankAccount, BankAccountClosed,
                   Currencies, FinancialCategories,
-                  Transaction, Bank,
+                  Transaction,
                   Calendar,
                   TransactionDetails, Close,
                   DialogOK, DialogClose, DialogCancel,
                   DialogOKApply, DialogError, DialogWarning,
                   DialogInformation,
                   ListExpand, ListCollapse,
-                  ListAdd, ListAddUser, ListRemoveUser,
-                  ListAddTag, ListRemoveTag,
+                  ListAdd, PayeeNew, PayeeRemove,
+                  TagNew, TagRemove,
                   GoTo, KeyEnter, Download, TagRename,
-                  EditDelete, EditCopy, EditRename,
+                  EditRemove, EditShred, EditCopy, EditRename,
                   Find, EditUndo, EditClear,
                   DocumentEdit,
                   DocumentNew, DocumentSave,
                   DocumentClose, DocumentOpen,
                   DocumentImport, DocumentExport,
-                  OfficeChartLine,
-                  MailMessageNew, MailMessage, MailReceive,
+                  OfficeCharBar, OfficeChartLineForecast,
+                  MailMessage, MailSend, MailReceive,
                   MapOnlineAccount, UnmapOnlineAccount,
+                  Globe,
                   NewSchedule, KMyMoney,
                   PayeeRename, PayeeMerge,
                   Configure,
-                  Reconciled, AccountClosed, Unknown,
+                  TransactionStateReconciled, Unknown,
                   Report, Refresh, PreferencesGeneral,
                   SortAscending, SortDescending,
+                  ItemExchange,
                   ArrowUp, ArrowDown, ArrowRight, ArrowLeft,
-                  Warning, TaskComplete,
-                  TaskReject, TaskAccepted, TaskOngoing,
-                  Help, Folder,
+                  TaskComplete,
+                  TaskReject, TaskAccepted, TaskOngoing, TaskPending,
+                  Help, Community, Folder,
                   PreferencesFonts, PreferencesColors, PreferencesIcons,
                   PreferencesNetwork, PreferencesPlugins,
                   Empty,
-                  InstitutionNew, InstitutionEdit, InstitutionDelete,
-                  AccountNew, AccountEdit, AccountDelete,
+                  InstitutionNew, InstitutionEdit, InstitutionRemove,
+                  AccountNew, AccountEdit, AccountRemove,
                   AccountClose, AccountReopen,
                   AccountUpdate, AccountUpdateAll,
-                  AccountCreditTransfer, AccountFinishReconciliation,
-                  CategoryNew, CategoryEdit, CategoryDelete,
-                  TransactionNew, TransactionEdit,
-                  TransactionMatch, TransactionAccept,
+                  OnlineTransfer, Reconciled,
+                  FinancialCategoryNew, FinancialCategoryEdit, FinancialCategoryRemove,
+                  TransactionStateAny, TransactionStateImported, TransactionStateMatched,
+                  TransactionStateErroneous, TransactionStateScheduled, TransactionStateNotReconciled,
+                  TransactionStateNotMarked, TransactionStateCleared,
                   InvestmentNew, InvestmentEdit,
-                  InvestmentDelete, InvestmentOnlinePrice,
-                  BudgetNew, BudgetRename, BudgetDelete, BudgetCopy,
-                  PriceUpdate, InvestmentOnlinePriceAll, Reverse, Visibility, NoVisibility,
-                  SelectAll,
+                  InvestmentRemove, OnlinePriceUpdate,
+                  Reverse, Visibility, NoVisibility,
+                  SelectAll, Backup, Vault,
                 };
 // clang-format on
 
-KMM_ICONS_EXPORT void setUpMappings(const QString & themeName);
 KMM_ICONS_EXPORT QIcon get(Icons::Icon icon);
 
 
