@@ -27,14 +27,15 @@
 
 #include "kmymoneyutils.h"
 
-#include "mymoneyaccount.h"
 #include "mymoney/onlinejob.h"
-#include "onlinejobtyped.h"
+#include "mymoneyaccount.h"
+#include "mymoneyenums.h"
+#include "mymoneyfactory.h"
 #include "mymoneykeyvaluecontainer.h"
 #include "mymoneymoney.h"
 #include "mymoneysplit.h"
 #include "mymoneytransaction.h"
-#include "mymoneyenums.h"
+#include "onlinejobtyped.h"
 #include "viewenums.h"
 
 class QResizeEvent;
@@ -88,7 +89,7 @@ enum class Menu;
   *
   * @short Main application class.
   */
-class KMyMoneyApp : public KXmlGuiWindow, public IMyMoneyProcessingCalendar
+class KMyMoneyApp : public KXmlGuiWindow, public IMyMoneyProcessingCalendar, public MyMoneyFactory
 {
     Q_OBJECT
 
@@ -376,6 +377,8 @@ public:
 
     void consistencyCheck(bool alwaysDisplayResult);
 
+    void applyFileFixes() const;
+
 protected:
     /** save general Options like all bar positions and status as well as the geometry and the recent file list to the configuration
      * file
@@ -438,9 +441,9 @@ protected:
 
 public Q_SLOTS:
 
-    void slotFileInfoDialog();
+    QObject* createFactoryObject(QObject* parent, const QString& objectName) override;
 
-    bool isFileOpenedInAnotherInstance(const QUrl &url);
+    void slotFileInfoDialog();
 
     void slotFileConsistencyCheck();
 
