@@ -123,15 +123,16 @@ class MyMoneyAccount;
 class MyMoneyInstitution;
 class MyMoneySecurity;
 class MyMoneyPrice;
+class MyMoneyMoney;
 typedef QPair<QString, QString> MyMoneySecurityPair;
 typedef QMap<QDate, MyMoneyPrice> MyMoneyPriceEntries;
 typedef QMap<MyMoneySecurityPair, MyMoneyPriceEntries> MyMoneyPriceList;
+typedef QMap<QString, MyMoneyMoney> AccountBalanceCache;
 class MyMoneySchedule;
 class MyMoneyTag;
 class MyMoneyPayee;
 class MyMoneyBudget;
 class MyMoneyReport;
-class MyMoneyMoney;
 class MyMoneySplit;
 class MyMoneyObject;
 class MyMoneyTransaction;
@@ -210,9 +211,11 @@ public:
 
     /**
      * This returns the currently implemented highest fix version
+     *
+     * @note keep in sync with MyMoneyDbDef::m_currentVersion
      */
     constexpr static int availableFixVersion() {
-        return 6;
+        return 8;
     }
 
     /**
@@ -1205,8 +1208,7 @@ public:
      *
      * @returns adjusted transaction
      */
-    MyMoneyTransaction scheduledTransaction(const MyMoneySchedule& schedule);
-
+    MyMoneyTransaction scheduledTransaction(const MyMoneySchedule& schedule, const AccountBalanceCache& balances) const;
 
     QStringList consistencyCheck();
 
@@ -1778,6 +1780,8 @@ public:
     bool hasValidId (const MyMoneyAccount& acc) const;
     bool hasValidId (const MyMoneyPayee& payee) const;
 
+    bool applyFileFixes(bool expertMode);
+
 protected:
     /**
       * This is the constructor for a new empty file description
