@@ -23,16 +23,25 @@
 // ----------------------------------------------------------------------------
 // Project Includes
 
-#include "csvwizard.h"
 #include "core/csvimportercore.h"
+#include "csvwizard.h"
 #include "icons.h"
+#include "mymoneyqifprofile.h"
+
 #include "ui_bankingwizardpage.h"
 
+#include "kmmyesno.h"
+
 // ----------------------------------------------------------------------------
 
 #define connectClearButton(col) \
   connect(ui->col ## Clear, &QToolButton::clicked, this, [&]() { clearComboBox(ui->col ); } );
 
+static void clearComboBox(QComboBox* combobox)
+{
+    combobox->setCurrentIndex(-1);
+}
+
 BankingPage::BankingPage(CSVWizard *dlg, CSVImporterCore *imp)
     : CSVWizardPage(dlg, imp)
     , m_profile(nullptr)
@@ -53,10 +62,6 @@ BankingPage::BankingPage(CSVWizard *dlg, CSVImporterCore *imp)
         {Column::Balance, ui->m_balanceCol},
     };
 
-    auto clearComboBox = [&](QComboBox* combobox) {
-        combobox->setCurrentIndex(-1);
-    };
-
     connect(ui->m_clear, &QAbstractButton::clicked, this, &BankingPage::clearColumns);
     connect(ui->m_oppositeSigns, &QAbstractButton::clicked, this, [&](bool checked) {
         m_profile->m_oppositeSigns = checked;
@@ -72,32 +77,35 @@ BankingPage::BankingPage(CSVWizard *dlg, CSVImporterCore *imp)
     });
 
     void (QComboBox::* signal)(int) = &QComboBox::currentIndexChanged;
-    connect(ui->m_amountCol, signal, this, [&](int col) {
+    connect(ui->m_amountCol, signal, this, [&](int col) { // clazy:exclude=connect-non-signal
         validateSelectedColumn(col, Column::Amount);
     });
-    connect(ui->m_debitCol, signal, this, [&](int col) {
+    connect(ui->m_debitCol, signal, this, [&](int col) { // clazy:exclude=connect-non-signal
         validateSelectedColumn(col, Column::Debit);
     });
-    connect(ui->m_creditCol, signal, this, [&](int col) {
+    connect(ui->m_creditCol, signal, this, [&](int col) { // clazy:exclude=connect-non-signal
         validateSelectedColumn(col, Column::Credit);
     });
-    connect(ui->m_numberCol, signal, this, [&](int col) {
+    connect(ui->m_numberCol, signal, this, [&](int col) { // clazy:exclude=connect-non-signal
         validateSelectedColumn(col, Column::Number);
     });
-    connect(ui->m_dateCol, signal, this, [&](int col) {
+    connect(ui->m_dateCol, signal, this, [&](int col) { // clazy:exclude=connect-non-signal
         validateSelectedColumn(col, Column::Date);
     });
-    connect(ui->m_categoryCol, signal, this, [&](int col) {
+    connect(ui->m_categoryCol, signal, this, [&](int col) { // clazy:exclude=connect-non-signal
         validateSelectedColumn(col, Column::Category);
     });
-
-    connect(ui->m_creditIndicator, &QLineEdit::textEdited, [&](const QString& indicator) {
-        m_profile->m_creditIndicator = indicator;
-        emit completeChanged();
+    connect(ui->m_balanceCol, signal, this, [&](int col) { // clazy:exclude=connect-non-signal
+        validateSelectedColumn(col, Column::Balance);
     });
-    connect(ui->m_debitIndicator, &QLineEdit::textEdited, [&](const QString&  indicator) {
+
+    connect(ui->m_creditIndicator, &QLineEdit::textEdited, this, [&](const QString& indicator) {
+        m_profile->m_creditIndicator = indicator;
+        Q_EMIT completeChanged();
+    });
+    connect(ui->m_debitIndicator, &QLineEdit::textEdited, this, [&](const QString& indicator) {
         m_profile->m_debitIndicator = indicator;
-        emit completeChanged();
+        Q_EMIT completeChanged();
     });
 
     connect(ui->m_memoCol, signal, this, &BankingPage::memoColSelected);
@@ -201,17 +209,8 @@ int BankingPage::nextId() const
 
 bool BankingPage::isComplete() const
 {
-    // the settings are complete, if we
-    // a) have a date and,
-    // if the amount option is selected
-    //   b) an amount
-    //   c) a debit and/or credit indicator if that option is selected
-    //      and they differ
-    // if the debit/credit option is selected
-    //   b) a debit and credit column
-    //
-    // other columns are optional
-    bool rc = (ui->m_dateCol->currentIndex() > -1);
+    bool rc = (ui->m_dateCol->currentIndex() > -1) &&
+              (ui->m_payeeCol->currentIndex() > -1);
 
     if (ui->m_amountTabWidget->currentIndex() == 0) { // amountTab selected
         rc &= (ui->m_amountCol->currentIndex() > -1);
@@ -249,12 +248,16 @@ void BankingPage::memoColSelected(int col)
 {
     if (col != -1) {
         if (m_profile->m_colNumType.value(col) == Column::Payee ) {
-            int rc = KMessageBox::Yes;
+            int rc = KMessageBox::PrimaryAction;
             if (isVisible())
-                rc = KMessageBox::questionYesNo(m_dlg, i18n("<center>The '<b>%1</b>' field already has this column selected.</center>"
-                                                "<center>If you wish to copy the Payee data to the memo field, click 'Yes'.</center>",
-                                                m_dlg->m_colTypeName.value(m_profile->m_colNumType.value(col))));
-            if (rc == KMessageBox::Yes) {
+                rc = KMessageBox::questionTwoActions(m_dlg,
+                                                     i18n("<center>The '<b>%1</b>' field already has this column selected.</center>"
+                                                          "<center>If you wish to copy the Payee data to the memo field, click 'Yes'.</center>",
+                                                          m_dlg->m_colTypeName.value(m_profile->m_colNumType.value(col))),
+                                                     i18nc("@title:window", "Field assignment resolution"),
+                                                     KMMYesNo::yes(),
+                                                     KMMYesNo::no());
+            if (rc == KMessageBox::PrimaryAction) {
                 ui->m_memoCol->setItemText(col, QString::number(col + 1) + QLatin1Char('*'));
                 if (!m_profile->m_memoColList.contains(col))
                     m_profile->m_memoColList.append(col);
@@ -313,7 +316,7 @@ void BankingPage::payeeColSelected(int col)
 
 void BankingPage::clearColumns()
 {
-    for (const auto& comboBox : m_columnBoxes) {
+    for (const auto& comboBox : qAsConst(m_columnBoxes)) {
         comboBox->setCurrentIndex(-1);
     }
     ui->m_creditIndicator->clear();
@@ -342,7 +345,7 @@ void BankingPage::resetComboBox(Column comboBox, int index)
     if (m_columnBoxes.contains(comboBox)) {
         m_columnBoxes.value(comboBox)->setCurrentIndex(index);
     } else {
-        KMessageBox::sorry(m_dlg, i18n("<center>Field name not recognised.</center> <center>'<b>%1</b>'</center> Please re-enter your column selections."
+        KMessageBox::error(m_dlg, i18n("<center>Field name not recognised.</center> <center>'<b>%1</b>'</center> Please re-enter your column selections."
                                        , static_cast<int>(comboBox)), i18n("CSV import"));
     }
 }
@@ -370,7 +373,7 @@ bool BankingPage::validateSelectedColumn(const int col, const Column type)
         m_profile->m_colTypeNum[type] = col; // assign new column 'number' to this 'type'
         m_profile->m_colNumType[col] = type; // assign new 'type' to this column 'number'
     }
-    emit completeChanged();
+    Q_EMIT completeChanged();
     return ret;
 }
 
@@ -384,25 +387,25 @@ bool BankingPage::validateCreditDebit()
             QString debit = m_imp->m_file->m_model->item(row, m_profile->m_colTypeNum.value(Column::Debit))->text();
             m_imp->processCreditDebit(credit, debit);
             if (!credit.isEmpty() && !debit.isEmpty()) {
-                int ret = KMessageBox::questionYesNoCancel(m_dlg,
-                          i18n("<center>The %1 field contains '%2'</center>"
-                               "<center>and the %3 field contains '%4'.</center>"
-                               "<center>Please choose which you wish to accept.</center>",
-                               m_dlg->m_colTypeName.value(Column::Debit),
-                               debit,
-                               m_dlg->m_colTypeName.value(Column::Credit),
-                               credit),
-                          i18n("CSV invalid field values"),
-                          KGuiItem(i18n("Accept %1", m_dlg->m_colTypeName.value(Column::Debit))),
-                          KGuiItem(i18n("Accept %1", m_dlg->m_colTypeName.value(Column::Credit))),
-                          KGuiItem(i18n("Cancel")));
+                int ret = KMessageBox::questionTwoActionsCancel(m_dlg,
+                                                                i18n("<center>The %1 field contains '%2'</center>"
+                                                                     "<center>and the %3 field contains '%4'.</center>"
+                                                                     "<center>Please choose which you wish to accept.</center>",
+                                                                     m_dlg->m_colTypeName.value(Column::Debit),
+                                                                     debit,
+                                                                     m_dlg->m_colTypeName.value(Column::Credit),
+                                                                     credit),
+                                                                i18n("CSV invalid field values"),
+                                                                KGuiItem(i18n("Accept %1", m_dlg->m_colTypeName.value(Column::Debit))),
+                                                                KGuiItem(i18n("Accept %1", m_dlg->m_colTypeName.value(Column::Credit))),
+                                                                KGuiItem(i18n("Cancel")));
                 switch(ret) {
                 case KMessageBox::Cancel:
                     return false;
-                case KMessageBox::Yes:
+                case KMessageBox::PrimaryAction:
                     m_imp->m_file->m_model->item(row, m_profile->m_colTypeNum.value(Column::Credit))->setText(QString());
                     break;
-                case KMessageBox::No:
+                case KMessageBox::SecondaryAction:
                     m_imp->m_file->m_model->item(row, m_profile->m_colTypeNum.value(Column::Debit))->setText(QString());
                     break;
                 }
@@ -412,7 +415,7 @@ bool BankingPage::validateCreditDebit()
     return true;
 }
 
-void BankingPage::makeQIF(const MyMoneyStatement& st, const QString& outFileName)
+void BankingPage::makeQIF(const MyMoneyStatement& st, const QString& outFileName, const MyMoneyQifProfile& qifProfile)
 {
     QFile oFile(outFileName);
     oFile.open(QIODevice::WriteOnly);
@@ -431,27 +434,30 @@ void BankingPage::makeQIF(const MyMoneyStatement& st, const QString& outFileName
         strEType = QStringLiteral("Bank");
     }
 
+    const auto eol(QLatin1Char('\n'));
+
     if (!st.m_strAccountName.isEmpty()) {
         buffer.append(QStringLiteral("!Account\n"));
-        buffer.append(QChar(QLatin1Char('N')) + st.m_strAccountName + QChar(QLatin1Char('\n')));
-        buffer.append(QChar(QLatin1Char('T')) + strEType + QChar(QLatin1Char('\n')));
+        buffer.append(QLatin1Char('N') + st.m_strAccountName + eol);
+        buffer.append(QLatin1Char('T') + strEType + eol);
         buffer.append(QStringLiteral("^\n"));
     }
 
-    buffer.append(QStringLiteral("!Type:") + strEType + QChar(QLatin1Char('\n')));
+    buffer.append(QStringLiteral("!Type:") + strEType + eol);
 
-    for (QList<MyMoneyStatement::Transaction>::const_iterator it = st.m_listTransactions.constBegin(); it != st.m_listTransactions.constEnd(); ++it) {
-        buffer.append(QChar(QLatin1Char('D')) + it->m_datePosted.toString(QStringLiteral("MM/dd/yyyy")) + QChar(QLatin1Char('\n')));
-        QString txt;
-        txt.setNum(it->m_amount.toDouble(), 'f', 4);
-        buffer.append(QChar(QLatin1Char('T')) + txt + QChar(QLatin1Char('\n')));
-        buffer.append(QChar(QLatin1Char('P')) + it->m_strPayee + QChar(QLatin1Char('\n')));
-        if (!it->m_listSplits.isEmpty())
-            buffer.append(QChar(QLatin1Char('L')) + it->m_listSplits.first().m_strCategoryName + QChar(QLatin1Char('\n')));
-        if (!it->m_strNumber.isEmpty())
-            buffer.append(QChar(QLatin1Char('N')) + it->m_strNumber + QChar(QLatin1Char('\n')));
-        if (!it->m_strMemo.isEmpty())
-            buffer.append(QChar(QLatin1Char('M')) + it->m_strMemo + QChar(QLatin1Char('\n')));
+    for (QList<MyMoneyStatement::Transaction>::const_iterator it = st.m_listTransactions.cbegin(); it != st.m_listTransactions.cend(); ++it) {
+        buffer.append(QLatin1Char('D') + qifProfile.date(it->m_datePosted) + eol);
+        buffer.append(QLatin1Char('T') + qifProfile.value(QLatin1Char('T'), it->m_amount) + eol);
+        buffer.append(QLatin1Char('P') + it->m_strPayee + eol);
+        if (!it->m_listSplits.isEmpty()) {
+            buffer.append(QLatin1Char('L') + it->m_listSplits.first().m_strCategoryName + eol);
+        }
+        if (!it->m_strNumber.isEmpty()) {
+            buffer.append(QLatin1Char('N') + it->m_strNumber + eol);
+        }
+        if (!it->m_strMemo.isEmpty()) {
+            buffer.append(QLatin1Char('M') + it->m_strMemo + eol);
+        }
         buffer.append(QStringLiteral("^\n"));
         out << buffer;// output qif file
         buffer.clear();
