@@ -1,7 +1,7 @@
 /*
     SPDX-FileCopyrightText: 2015-2016 Allan Anderson <agander93@gmail.com>
     SPDX-FileCopyrightText: 2016-2018 Łukasz Wojniłowicz <lukasz.wojnilowicz@gmail.com>
-    SPDX-FileCopyrightText: 2018 Thomas Baumgart <tbaumgart@kde.org>
+    SPDX-FileCopyrightText: 2018-2020 Thomas Baumgart <tbaumgart@kde.org>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
@@ -10,15 +10,15 @@
 // ----------------------------------------------------------------------------
 // QT Includes
 
-#include <QAction>
-#include <QDesktopWidget>
-#include <QTextCodec>
 #include <QAbstractButton>
+#include <QAction>
 #include <QFileDialog>
-#include <QStandardItemModel>
-#include <QScrollBar>
-#include <QLineEdit>
 #include <QKeyEvent>
+#include <QLineEdit>
+#include <QScreen>
+#include <QScrollBar>
+#include <QStandardItemModel>
+#include <QTextCodec>
 
 // ----------------------------------------------------------------------------
 // KDE Includes
@@ -31,14 +31,17 @@
 // ----------------------------------------------------------------------------
 // Project Includes
 
-#include "csvimporter.h"
-#include "core/csvutil.h"
+#include "bankingwizardpage.h"
 #include "core/convdate.h"
 #include "core/csvimportercore.h"
+#include "core/csvutil.h"
+#include "csvimporter.h"
+#include "icons.h"
 #include "investmentwizardpage.h"
-#include "bankingwizardpage.h"
+#include "mymoneyqifprofile.h"
+#include "pluginsettings.h"
 #include "priceswizardpage.h"
-#include "icons/icons.h"
+
 #include "ui_csvwizard.h"
 #include "ui_introwizardpage.h"
 #include "ui_separatorwizardpage.h"
@@ -47,12 +50,13 @@
 
 using namespace Icons;
 
-CSVWizard::CSVWizard(CSVImporter *plugin) :
-    ui(new Ui::CSVWizard),
-    m_skipSetup(false),
-    m_plugin(plugin),
-    m_imp(new CSVImporterCore),
-    m_wiz(new QWizard)
+CSVWizard::CSVWizard(QWidget* parentWidget, CSVImporter* plugin)
+    : QDialog(parentWidget)
+    , ui(new Ui::CSVWizard)
+    , m_skipSetup(false)
+    , m_plugin(plugin)
+    , m_imp(new CSVImporterCore)
+    , m_wiz(new QWizard)
 {
     ui->setupUi(this);
     ui->tableView->setModel(m_imp->m_file->m_model);
@@ -92,7 +96,7 @@ CSVWizard::CSVWizard(CSVImporter *plugin) :
     connect(m_wiz->button(QWizard::CancelButton), &QAbstractButton::clicked, this, &CSVWizard::reject);
     connect(m_wiz->button(QWizard::CustomButton1), &QAbstractButton::clicked, this, &CSVWizard::fileDialogClicked);
     connect(m_wiz->button(QWizard::CustomButton2), &QAbstractButton::clicked, this, &CSVWizard::saveAsQIFClicked);
-    connect(m_wiz, SIGNAL(currentIdChanged(int)), this, SLOT(slotIdChanged(int)));
+    connect(m_wiz, &QWizard::currentIdChanged, this, &CSVWizard::slotIdChanged);
 
     ui->tableView->setWordWrap(false);
 
@@ -169,7 +173,7 @@ void CSVWizard::clearColumnsBackground(const QList<int> &columnList)
 {
     QStandardItemModel *model = m_imp->m_file->m_model;
     for (int i = m_imp->m_profile->m_startLine; i <= m_imp->m_profile->m_endLine; ++i) {
-        foreach (const auto j, columnList) {
+        for (const auto j : columnList) {
             model->item(i, j)->setBackground(m_clearBrush);
             model->item(i, j)->setForeground(m_clearBrushText);
         }
@@ -213,12 +217,12 @@ void CSVWizard::markUnwantedRows()
 
 void CSVWizard::updateWindowSize()
 {
-    QTableView *table = this->ui->tableView;
+    const auto table = ui->tableView;
     table->resizeColumnsToContents();
-    this->repaint();
+    repaint();
 
-    QRect screen = QApplication::desktop()->availableGeometry();    //get available screen size
-    QRect wizard = this->frameGeometry();                           //get current wizard size
+    QSize screenSize = screen()->size(); // get available screen size
+    QRect wizard = frameGeometry(); // get current wizard size
 
     int newWidth = (table->contentsMargins().left() //
                     + table->contentsMargins().right() //
@@ -248,27 +252,28 @@ void CSVWizard::updateWindowSize()
     }
 
     // limit wizard size to screen size
-    if (newHeight > screen.height())
-        newHeight = screen.height();
-
-    if (newWidth > screen.width())
-        newWidth = screen.width();
+    if (newHeight > screenSize.height())
+        newHeight = screenSize.height();
 
+    if (newWidth > screenSize.width())
+        newWidth = screenSize.width();
 
     // don't shrink wizard if required size is less than initial
-    if (newWidth < this->m_initialWidth)
-        newWidth = this->m_initialWidth;
-    if (newHeight < this->m_initialHeight)
-        newHeight = this->m_initialHeight;
+    if (newWidth < m_initialWidth)
+        newWidth = m_initialWidth;
+    if (newHeight < m_initialHeight)
+        newHeight = m_initialHeight;
 
-    newWidth -= (wizard.width() - this->geometry().width());      // remove window frame
-    newHeight -= (wizard.height() - this->geometry().height());
+    newWidth -= (wizard.width() - geometry().width()); // remove window frame
+    newHeight -= (wizard.height() - geometry().height());
 
     wizard.setWidth(newWidth);
     wizard.setHeight(newHeight);
-    wizard.moveTo((screen.width() - wizard.width()) / 2,
-                  (screen.height() - wizard.height()) / 2);
-    this->setGeometry(wizard);
+
+    const auto topLeftOfScreen = screen()->geometry().topLeft();
+    const auto newPos = QPoint((screenSize.width() - wizard.width()) / 2, (screenSize.height() - wizard.height()) / 2);
+    wizard.moveTo(topLeftOfScreen + newPos);
+    setGeometry(wizard);
 }
 
 bool CSVWizard::eventFilter(QObject *object, QEvent *event)
@@ -408,12 +413,15 @@ void CSVWizard::saveAsQIFClicked()
     outFileName = QFileDialog::getSaveFileName(this, i18n("Save QIF"), outFileName, i18n("QIF Files (*.qif)"));
     if (outFileName.isEmpty())
         return;
+
+    MyMoneyQifProfile qifProfile(PluginSettings::qifExportProfile());
+
     switch (m_imp->m_profile->type()) {
     case Profile::Banking:
-        m_pageBanking->makeQIF(m_st, outFileName);
+        m_pageBanking->makeQIF(m_st, outFileName, qifProfile);
         break;
     case Profile::Investment:
-        m_pageInvestment->makeQIF(m_st, outFileName);
+        m_pageInvestment->makeQIF(m_st, outFileName, qifProfile);
         break;
     default:
         break;
@@ -426,7 +434,7 @@ void CSVWizard::initializeComboBoxes(const QHash<Column, QComboBox *> &columns)
     for (int i = 0; i < m_imp->m_file->m_columnCount; ++i)
         columnNumbers.append(QString::number(i + 1));
 
-    foreach (const auto column, columns) {
+    for (const auto& column : columns) {
         // block signals from combobox during their initialization
         QSignalBlocker blocker(column);
         // clear all existing items before adding new ones
@@ -471,7 +479,7 @@ void IntroPage::initializePage()
 
     ui->m_profiles->lineEdit()->setClearButtonEnabled(true);
 
-    connect(ui->m_profiles, SIGNAL(currentIndexChanged(int)), this, SLOT(slotComboSourceIndexChanged(int)));
+    connect(ui->m_profiles, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &IntroPage::slotComboSourceIndexChanged);
     connect(ui->m_add, &QAbstractButton::clicked, this, &IntroPage::slotAddProfile);
     connect(ui->m_remove, &QAbstractButton::clicked, this, &IntroPage::slotRemoveProfile);
     connect(ui->m_rename, &QAbstractButton::clicked, this, &IntroPage::slotRenameProfile);
@@ -485,13 +493,10 @@ void IntroPage::initializePage()
     } else {
         //resize wizard to its initial size and center it
         m_dlg->setGeometry(
-            QStyle::alignedRect(
-                Qt::LeftToRight,
-                Qt::AlignCenter,
-                QSize(m_dlg->m_initialWidth, m_dlg->m_initialHeight),
-                QApplication::desktop()->availableGeometry()
-            )
-        );
+            QStyle::alignedRect(Qt::LeftToRight, Qt::AlignCenter, QSize(m_dlg->m_initialWidth, m_dlg->m_initialHeight), screen()->availableGeometry()));
+
+        // and make sure it shows up on the same monitor in multi monitor environments
+        m_dlg->move(m_dlg->pos() + m_dlg->parentWidget()->screen()->geometry().topLeft());
     }
     m_dlg->ui->tableView->hide();
 }
@@ -661,9 +666,9 @@ SeparatorPage::SeparatorPage(CSVWizard *dlg, CSVImporterCore *imp) :
     ui(new Ui::SeparatorPage)
 {
     ui->setupUi(this);
-    connect(ui->m_encoding, SIGNAL(currentIndexChanged(int)), this, SLOT(encodingChanged(int)));
-    connect(ui->m_fieldDelimiter, SIGNAL(currentIndexChanged(int)), this, SLOT(fieldDelimiterChanged(int)));
-    connect(ui->m_textDelimiter, SIGNAL(currentIndexChanged(int)), this, SLOT(textDelimiterChanged(int)));
+    connect(ui->m_encoding, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &SeparatorPage::encodingChanged);
+    connect(ui->m_fieldDelimiter, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &SeparatorPage::fieldDelimiterChanged);
+    connect(ui->m_textDelimiter, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &SeparatorPage::textDelimiterChanged);
 }
 
 SeparatorPage::~SeparatorPage()
@@ -688,9 +693,9 @@ void SeparatorPage::initializePage()
     ui->m_textDelimiter->blockSignals(false);
 
     // ... and ensure that their signal receivers will always be called
-    emit ui->m_encoding->currentIndexChanged(ui->m_encoding->currentIndex());
-    emit ui->m_fieldDelimiter->currentIndexChanged(ui->m_fieldDelimiter->currentIndex());
-    emit ui->m_textDelimiter->currentIndexChanged(ui->m_textDelimiter->currentIndex());
+    Q_EMIT ui->m_encoding->currentIndexChanged(ui->m_encoding->currentIndex());
+    Q_EMIT ui->m_fieldDelimiter->currentIndexChanged(ui->m_fieldDelimiter->currentIndex());
+    Q_EMIT ui->m_textDelimiter->currentIndexChanged(ui->m_textDelimiter->currentIndex());
     m_dlg->updateWindowSize();
 
     QList<QWizard::WizardButton> layout;
@@ -704,20 +709,22 @@ void SeparatorPage::initializeEncodingCombobox()
 
     QList<QTextCodec *>   codecs;
     QMap<QString, QTextCodec *> codecMap;
-    QRegExp iso8859RegExp(QLatin1Literal("ISO[- ]8859-([0-9]+).*"));
+    static const QRegularExpression iso8859RegExp(QLatin1String("ISO[- ]8859-([0-9]+).*"));
 
-    foreach (const auto mib, QTextCodec::availableMibs()) {
+    const auto availableMibs = QTextCodec::availableMibs();
+    for (const auto& mib : qAsConst(availableMibs)) {
         QTextCodec *codec = QTextCodec::codecForMib(mib);
 
         QString sortKey = codec->name().toUpper();
         int rank;
 
+        const auto iso8859(iso8859RegExp.match(sortKey));
         if (sortKey.startsWith(QLatin1String("UTF-8"))) {             // krazy:exclude=strings
             rank = 1;
         } else if (sortKey.startsWith(QLatin1String("UTF-16"))) {            // krazy:exclude=strings
             rank = 2;
-        } else if (iso8859RegExp.exactMatch(sortKey)) {
-            if (iso8859RegExp.cap(1).size() == 1)
+        } else if (iso8859.hasMatch()) {
+            if (iso8859.captured(1).size() == 1)
                 rank = 3;
             else
                 rank = 4;
@@ -730,7 +737,7 @@ void SeparatorPage::initializeEncodingCombobox()
     }
     codecs = codecMap.values();
 
-    foreach (const auto codec, codecs)
+    for (const auto codec : qAsConst(codecs))
         ui->m_encoding->addItem(codec->name(), codec->mibEnum());
 }
 
@@ -743,7 +750,7 @@ void SeparatorPage::encodingChanged(const int index)
         return;
     m_imp->m_profile->m_encodingMIBEnum = ui->m_encoding->currentData().toInt();
     m_imp->m_file->readFile(m_imp->m_profile);
-    emit completeChanged();
+    Q_EMIT completeChanged();
 }
 
 void SeparatorPage::fieldDelimiterChanged(const int index)
@@ -764,7 +771,7 @@ void SeparatorPage::fieldDelimiterChanged(const int index)
         ui->m_fieldDelimiter->blockSignals(false);
     }
     m_dlg->updateWindowSize();
-    emit completeChanged();
+    Q_EMIT completeChanged();
 }
 
 void SeparatorPage::textDelimiterChanged(const int index)
@@ -776,7 +783,7 @@ void SeparatorPage::textDelimiterChanged(const int index)
 
     m_imp->m_profile->m_textDelimiter = static_cast<TextDelimiter>(index);
     m_imp->m_file->setupParser(m_imp->m_profile);
-    emit completeChanged();
+    Q_EMIT completeChanged();
 }
 
 bool SeparatorPage::isComplete() const
@@ -826,8 +833,8 @@ RowsPage::RowsPage(CSVWizard *dlg, CSVImporterCore *imp) :
     connect(ui->m_headerHasName, &QAbstractButton::clicked, this, [&](bool checked) {
         m_imp->m_profile->m_autoAccountName = checked;
     });
-    connect(ui->m_startLine, SIGNAL(valueChanged(int)), this, SLOT(startRowChanged(int)));;
-    connect(ui->m_endLine, SIGNAL(valueChanged(int)), this, SLOT(endRowChanged(int)));
+    connect(ui->m_startLine, QOverload<int>::of(&QSpinBox::valueChanged), this, &RowsPage::startRowChanged);
+    connect(ui->m_endLine, QOverload<int>::of(&QSpinBox::valueChanged), this, &RowsPage::endRowChanged);
 }
 
 RowsPage::~RowsPage()
@@ -926,8 +933,8 @@ FormatsPage::FormatsPage(CSVWizard *dlg, CSVImporterCore *imp) :
     m_isDateFormatOK(false)
 {
     ui->setupUi(this);
-    connect(ui->m_dateFormat, SIGNAL(currentIndexChanged(int)), this, SLOT(dateFormatChanged(int)));
-    connect(ui->m_decimalSymbol, SIGNAL(currentIndexChanged(int)), this, SLOT(decimalSymbolChanged(int)));
+    connect(ui->m_dateFormat, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &FormatsPage::dateFormatChanged);
+    connect(ui->m_decimalSymbol, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &FormatsPage::decimalSymbolChanged);
 }
 
 FormatsPage::~FormatsPage()
@@ -957,7 +964,7 @@ void FormatsPage::initializePage()
     ui->m_dateFormat->blockSignals(true);
     ui->m_dateFormat->setCurrentIndex((int)m_imp->m_profile->m_dateFormat);
     ui->m_dateFormat->blockSignals(false);
-    emit ui->m_dateFormat->currentIndexChanged((int)m_imp->m_profile->m_dateFormat); // emit update signal manually regardless of change to combobox
+    Q_EMIT ui->m_dateFormat->currentIndexChanged((int)m_imp->m_profile->m_dateFormat); // Q_EMIT update signal manually regardless of change to combobox
 
     ui->m_decimalSymbol->blockSignals(true);
     if (m_imp->m_profile->m_decimalSymbol == DecimalSymbol::Auto && !m_imp->m_autodetect.value(AutoDecimalSymbol))
@@ -965,7 +972,7 @@ void FormatsPage::initializePage()
     else
         ui->m_decimalSymbol->setCurrentIndex((int)m_imp->m_profile->m_decimalSymbol);
     ui->m_decimalSymbol->blockSignals(false);
-    emit ui->m_decimalSymbol->currentIndexChanged((int)m_imp->m_profile->m_decimalSymbol); // emit update signal manually regardless of change to combobox
+    Q_EMIT ui->m_decimalSymbol->currentIndexChanged((int)m_imp->m_profile->m_decimalSymbol); // Q_EMIT update signal manually regardless of change to combobox
 }
 
 void FormatsPage::decimalSymbolChanged(int index)
@@ -984,14 +991,14 @@ void FormatsPage::decimalSymbolChanged(int index)
         m_imp->m_profile->m_decimalSymbol = DecimalSymbol::Auto;
         int failColumn = m_imp->detectDecimalSymbols(columns);
         if (failColumn != -2) {
-            KMessageBox::sorry(this, i18n("<center>Autodetect could not detect your decimal symbol in column %1.</center>"
+            KMessageBox::error(this, i18n("<center>Autodetect could not detect your decimal symbol in column %1.</center>"
                                           "<center>Try manual selection to see problematic cells and correct your data.</center>", failColumn), i18n("CSV import"));
             ui->m_decimalSymbol->setCurrentIndex(-1);
             ui->m_thousandsDelimiter->setCurrentIndex(-1);
         } else if (index == -1) { // if detection went well and decimal symbol was unspecified then we'll be specifying it
             DecimalSymbol firstDecSymbol = m_imp->m_decimalSymbolIndexMap.first();
             bool allSymbolsEqual = true;
-            foreach (const auto mapDecSymbol, m_imp->m_decimalSymbolIndexMap) {
+            for (const auto& mapDecSymbol : qAsConst(m_imp->m_decimalSymbolIndexMap)) {
                 if (firstDecSymbol != mapDecSymbol)
                     allSymbolsEqual = false;
             }
@@ -1009,20 +1016,20 @@ void FormatsPage::decimalSymbolChanged(int index)
         break;
     }
     default:
-        foreach (const auto column, columns)
+        for (const auto column : columns)
             m_imp->m_decimalSymbolIndexMap.insert(column, static_cast<DecimalSymbol>(index));
         ui->m_thousandsDelimiter->setCurrentIndex(index);
         m_imp->m_profile->m_decimalSymbol = static_cast<DecimalSymbol>(index);
     }
 
     m_isDecimalSymbolOK = validateDecimalSymbols(columns);
-    emit completeChanged();
+    Q_EMIT completeChanged();
 }
 
 bool FormatsPage::validateDecimalSymbols(const QList<int> &columns)
 {
     bool isOK = true;
-    foreach (const auto col, columns) {
+    for (const auto col : columns) {
         m_imp->m_file->m_parse->setDecimalSymbol(m_imp->m_decimalSymbolIndexMap.value(col));
         m_dlg->clearColumnsBackground(col);
         for (int row = m_imp->m_profile->m_startLine; row <= m_imp->m_profile->m_endLine; ++row) {
@@ -1040,7 +1047,6 @@ bool FormatsPage::validateDecimalSymbols(const QList<int> &columns)
                 item->setForeground(m_dlg->m_errorBrushText);
             }
         }
-
     }
     return isOK;
 }
@@ -1055,11 +1061,11 @@ void FormatsPage::dateFormatChanged(const int index)
     m_imp->m_convertDate->setDateFormatIndex(static_cast<DateFormat>(index));
     m_isDateFormatOK = validateDateFormat(col);
     if (!m_isDateFormatOK) {
-        KMessageBox::sorry(this, i18n("<center>There are invalid date formats in column '%1'.</center>"
+        KMessageBox::error(this, i18n("<center>There are invalid date formats in column '%1'.</center>"
                                       "<center>Please check your selections.</center>"
                                       , col + 1), i18n("CSV import"));
     }
-    emit completeChanged();
+    Q_EMIT completeChanged();
 }
 
 bool FormatsPage::validateDateFormat(const int col)
@@ -1087,9 +1093,26 @@ bool FormatsPage::validateDateFormat(const int col)
 bool FormatsPage::isComplete() const
 {
     const bool enable = m_isDecimalSymbolOK && m_isDateFormatOK;
-    if (m_imp->m_profile->type() != Profile::StockPrices &&
-            m_imp->m_profile->type() != Profile::CurrencyPrices)
-        wizard()->button(QWizard::CustomButton2)->setEnabled(enable);
+    const auto button = wizard()->button(QWizard::CustomButton2);
+
+    if ((m_imp->m_profile->type() != Profile::StockPrices) && (m_imp->m_profile->type() != Profile::CurrencyPrices)) {
+        if (enable) {
+            // check if QIF profile exists and is selected
+            QStringList profileList;
+            KSharedConfigPtr config = KSharedConfig::openConfig();
+            KConfigGroup grp = config->group("Profiles");
+            profileList = grp.readEntry("profiles", QStringList());
+
+            const auto profile = PluginSettings::qifExportProfile();
+
+            if (profile.isEmpty() || profileList.contains(profile)) {
+                button->setEnabled(true);
+                button->setToolTip(QString());
+            } else {
+                button->setToolTip(i18nc("@info:tooltip QIF profile not selected", "Please select a QIF profile in the CSV importer settings"));
+            }
+        }
+    }
     return enable;
 }
 
