@@ -42,9 +42,11 @@
 #include "mymoneyexception.h"
 #include "mymoneystatement.h"
 #include "mymoneystatementreader.h"
+#include "selectedobjects.h"
 #include "statementinterface.h"
 #include "ui_importoption.h"
 #include "viewinterface.h"
+
 #include <libofx/libofx.h>
 
 // #define DEBUG_LIBOFX
@@ -61,6 +63,7 @@ public:
     Private()
         : m_valid(false)
         , m_preferName(PreferId)
+        , m_preferredPrice(PriceField)
         , m_uniqueIdSource(UniqueIdUnknown)
         , m_invertAmount(false)
         , m_fixBuySellSignage(false)
@@ -77,6 +80,10 @@ public:
         PreferName,
         PreferMemo,
     } m_preferName;
+    enum PricePreference {
+        PriceField,
+        ValueAndShares,
+    } m_preferredPrice;
     UniqueTransactionIdSource m_uniqueIdSource;
     bool m_invertAmount;
     bool m_fixBuySellSignage;
@@ -91,6 +98,7 @@ public:
     QDate m_updateStartDate;
     int m_timestampOffset;
     KMMStringSet m_hashes;
+    SelectedObjects m_selections;
 
     int constructTimeOffset(const QTimeEdit* timestampOffset, const KComboBox* timestampOffsetSign) const
     {
@@ -171,6 +179,7 @@ void OFXImporter::slotImportFile()
                                              widget);
 
     d->m_preferName = static_cast<OFXImporter::Private::NamePreference>(option->m_preferName->currentIndex());
+    d->m_preferredPrice = static_cast<OFXImporter::Private::PricePreference>(option->m_preferredPrice->currentIndex());
     d->m_uniqueIdSource = static_cast<UniqueTransactionIdSource>(option->m_uniqueIdSource->currentIndex());
     d->m_timestampOffset = d->constructTimeOffset(option->m_timestampOffset, option->m_timestampOffsetSign);
     d->m_invertAmount = option->m_invertAmount->isChecked();
@@ -205,6 +214,7 @@ bool OFXImporter::isMyFormat(const QString& filename) const
     // the tag "<OFX>" or "<OFC>" in the first 20 lines.
     // which contain some data
     bool result = false;
+    QRegularExpression re(QStringLiteral("<\\s*OF[XC]\\s*>"), QRegularExpression::CaseInsensitiveOption);
 
     QFile f(filename);
     if (f.open(QIODevice::ReadOnly | QIODevice::Text)) {
@@ -212,11 +222,11 @@ bool OFXImporter::isMyFormat(const QString& filename) const
 
         int lineCount = 20;
         while (!ts.atEnd() && !result  && lineCount != 0) {
-            // get a line of data and remove all unnecessary whitepace chars
+            // get a line of data and remove all unnecessary whitespace chars
             QString line = ts.readLine().simplified();
-            if (line.contains(QStringLiteral("<OFX>"), Qt::CaseInsensitive)
-                    || line.contains(QStringLiteral("<OFC>"), Qt::CaseInsensitive))
+            if (re.match(line).hasMatch()) {
                 result = true;
+            }
             // count only lines that contain some non white space chars
             if (!line.isEmpty())
                 lineCount--;
@@ -322,7 +332,7 @@ bool OFXImporter::import(const QString& filename)
 
 QString OFXImporter::lastError() const
 {
-    if (d->m_errors.count() == 0)
+    if (d->m_errors.isEmpty())
         return d->m_fatalerror;
     return d->m_errors.join(QStringLiteral("<p>"));
 }
@@ -617,6 +627,13 @@ int OFXImporter::ofxTransactionCallback(struct OfxTransactionData data, void * p
     if (data.unitprice_valid) {
         t.m_price = MyMoneyMoney(data.unitprice, 100000).reduce();
     }
+    // if there is no price provided or the price shall be
+    // derived from value and shares then calculate it but
+    // only if the dividend is not zero. the result certainly
+    // is always positive
+    if ((t.m_price.isZero() || d->m_preferredPrice == Private::ValueAndShares) && (!t.m_shares.isZero())) {
+        t.m_price = (t.m_amount / t.m_shares).abs();
+    }
 
     t.m_fees = MyMoneyMoney();
     if (data.fees_valid) {
@@ -911,8 +928,9 @@ MyMoneyKeyValueContainer OFXImporter::onlineBankingSettings(const MyMoneyKeyValu
         kvp.setValue(QStringLiteral("kmmofx-lastUpdate"), QString::number(d->m_statusDlg->m_lastUpdateRB->isChecked()));
         kvp.setValue(QStringLiteral("kmmofx-pickDate"), QString::number(d->m_statusDlg->m_pickDateRB->isChecked()));
         kvp.setValue(QStringLiteral("kmmofx-specificDate"), d->m_statusDlg->m_specificDate->date().toString());
-        kvp.setValue(QStringLiteral("kmmofx-preferName"), QString::number(d->m_statusDlg->m_preferredPayee->currentIndex()));
-        kvp.setValue(QStringLiteral("kmmofx-uniqueIdSource"), QString::number(d->m_statusDlg->m_uniqueTransactionId->currentIndex()));
+        kvp.setValue(QStringLiteral("kmmofx-preferName"), d->m_statusDlg->m_preferredPayee->currentIndex(), 0);
+        kvp.setValue(QStringLiteral("kmmofx-preferredPrice"), d->m_statusDlg->m_preferredPrice->currentIndex(), 0);
+        kvp.setValue(QStringLiteral("kmmofx-uniqueIdSource"), d->m_statusDlg->m_uniqueTransactionId->currentIndex(), 0);
         if (!d->m_statusDlg->m_clientUidEdit->text().isEmpty())
             kvp.setValue(QStringLiteral("clientUid"), d->m_statusDlg->m_clientUidEdit->text());
         else
@@ -969,11 +987,13 @@ bool OFXImporter::updateAccount(const MyMoneyAccount& acc, bool moreAccounts)
         d->m_uniqueIdSource = UniqueIdUnknown;
         if (!acc.id().isEmpty()) {
             // Save the value of preferName to be used by ofxTransactionCallback
-            d->m_preferName = static_cast<OFXImporter::Private::NamePreference>(acc.onlineBankingSettings().value(QStringLiteral("kmmofx-preferName")).toInt());
+            d->m_preferName = static_cast<OFXImporter::Private::NamePreference>(acc.onlineBankingSettings().value(QStringLiteral("kmmofx-preferName"), 0));
+            d->m_preferredPrice =
+                static_cast<OFXImporter::Private::PricePreference>(acc.onlineBankingSettings().value(QStringLiteral("kmmofx-preferredPrice"), 0));
             if (acc.onlineBankingSettings().value(QStringLiteral("kmmofx-uniqueIdSource")).isEmpty())
                 d->m_uniqueIdSource = defaultIdSource();
             else
-                d->m_uniqueIdSource = static_cast<UniqueTransactionIdSource>(acc.onlineBankingSettings().value(QStringLiteral("kmmofx-uniqueIdSource")).toInt());
+                d->m_uniqueIdSource = static_cast<UniqueTransactionIdSource>(acc.onlineBankingSettings().value(QStringLiteral("kmmofx-uniqueIdSource"), 0));
             QPointer<KOfxDirectConnectDlg> dlg = new KOfxDirectConnectDlg(acc);
 
             connect(dlg.data(), &KOfxDirectConnectDlg::statementReady, this, static_cast<void (OFXImporter::*)(const QString &)>(&OFXImporter::slotImportFile));
@@ -1108,6 +1128,11 @@ const QStringList& OFXImporter::errors() const
     return d->m_errors;
 }
 
+void OFXImporter::updateActions(const SelectedObjects& selections)
+{
+    d->m_selections = selections;
+}
+
 K_PLUGIN_CLASS_WITH_JSON(OFXImporter, "ofximporter.json")
 
 #include "ofximporter.moc"
