@@ -24,7 +24,7 @@
 #include <alkimia/alkvalue.h>
 
 //***************** THE CURRENT VERSION OF THE DATABASE LAYOUT ****************
-unsigned int MyMoneyDbDef::m_currentVersion = 12;
+unsigned int MyMoneyDbDef::m_currentVersion = 13; ///< @note keep in sync with MyMoneyFile::availableFixVersion()
 
 // ************************* Build table descriptions ****************************
 MyMoneyDbDef::MyMoneyDbDef()
@@ -142,8 +142,8 @@ void MyMoneyDbDef::Payees()
     appendField(MyMoneyDbIntColumn("matchData", MyMoneyDbIntColumn::TINY, UNSIGNED, false, false, 5));
     appendField(MyMoneyDbColumn("matchIgnoreCase", "char(1)", false, false, 5));
     appendField(MyMoneyDbTextColumn("matchKeys", MyMoneyDbTextColumn::MEDIUM, false, false, 5));
-    appendField(MyMoneyDbTextColumn("idPattern"));
-    appendField(MyMoneyDbTextColumn("urlTemplate"));
+    appendField(MyMoneyDbTextColumn("idPattern", MyMoneyDbTextColumn::NORMAL, false, false, 13));
+    appendField(MyMoneyDbTextColumn("urlTemplate", MyMoneyDbTextColumn::NORMAL, false, false, 13));
     MyMoneyDbTable t("kmmPayees", fields);
     t.buildSQLStrings();
     m_tables[t.name()] = t;
