@@ -1,5 +1,6 @@
 /*
     SPDX-FileCopyrightText: 2018 Łukasz Wojniłowicz <lukasz.wojnilowicz@gmail.com>
+    SPDX-FileCopyrightText: 2021 Dawid Wróbel <me@dawidwrobel.com>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
@@ -23,10 +24,10 @@ class OnlineJobOutboxView : public KMyMoneyPlugin::Plugin
     Q_OBJECT
 
 public:
-    explicit OnlineJobOutboxView(QObject *parent, const QVariantList &args);
-    ~OnlineJobOutboxView() final;
+    explicit OnlineJobOutboxView(QObject *parent, const KPluginMetaData &metaData, const QVariantList &args);
+    ~OnlineJobOutboxView();
 
-    void plug() final override;
+    void plug(KXMLGUIFactory* guiFactory) final override;
     void unplug() final override;
 
 private:
