@@ -1,5 +1,6 @@
 /*
     SPDX-FileCopyrightText: 2007-2018 Thomas Baumgart <tbaumgart@kde.org>
+    SPDX-FileCopyrightText: 2021 Dawid Wróbel <me@dawidwrobel.com>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
@@ -9,6 +10,7 @@
 // QT Includes
 
 #include <QFile>
+#include <QLocale>
 
 // ----------------------------------------------------------------------------
 // KDE Includes
@@ -18,19 +20,18 @@
 // ----------------------------------------------------------------------------
 // Project Includes
 
+#include "kmmurl.h"
 #include "kmymoneysettings.h"
 #include "kmymoneyutils.h"
+#include "mymoneyexception.h"
 #include "mymoneyfile.h"
 #include "mymoneysecurity.h"
-#include "mymoneyexception.h"
+#include "mymoneyutils.h"
 
 reports::ReportTable::ReportTable(const MyMoneyReport& _report):
-    m_resourceHtml("html"),
     m_reportStyleSheet("reportstylesheet"),
-    m_cssFileDefault("kmymoney.css"),
     m_config(_report),
     m_containsNonBaseCurrency(false)
-
 {
 }
 
@@ -40,7 +41,7 @@ QString reports::ReportTable::cssFileNameGet()
 
     if (!MyMoneyFile::instance()->value(m_reportStyleSheet).isEmpty()) {
         // try to find the stylesheet specific for this report
-        cssfilename = KMyMoneyUtils::findResource(QStandardPaths::AppDataLocation, m_resourceHtml + '/' + MyMoneyFile::instance()->value(m_reportStyleSheet));
+        cssfilename = QStandardPaths::locate(QStandardPaths::AppConfigLocation, "html/" + MyMoneyFile::instance()->value(m_reportStyleSheet));
     }
 
     if (cssfilename.isEmpty() || !QFile::exists(cssfilename)) {
@@ -48,54 +49,26 @@ QString reports::ReportTable::cssFileNameGet()
         cssfilename = KMyMoneySettings::cssFileDefault();
     }
 
-    if (cssfilename.isEmpty() || !QFile::exists(cssfilename)) {
-        // if there still is nothing, try to use the themed default
-        cssfilename = KMyMoneyUtils::findResource(QStandardPaths::AppConfigLocation, m_resourceHtml + '/' + m_cssFileDefault);
-    }
-
-    if (cssfilename.isEmpty() || !QFile::exists(cssfilename)) {
-        // if there still is nothing, try to use the installation default
-        cssfilename = KMyMoneyUtils::findResource(QStandardPaths::AppDataLocation, m_resourceHtml + '/' + m_cssFileDefault);
-    }
-
     return cssfilename;
 }
 
-QString reports::ReportTable::renderHeader(const QString& title, const QByteArray& encoding, bool includeCSS)
+QString reports::ReportTable::renderHeader(const QString& title, const QByteArray& encoding)
 {
-    QString header = QString("<!DOCTYPE HTML PUBLIC")
-                     + " \"-//W3C//DTD HTML 4.01 //EN\""
-                     + " \"http://www.w3.org/TR/html4/strict.dtd\">"
-                     + "\n<html>\n<head>"
-                     + "\n<meta http-equiv=\"Content-Type\""
-                     + " content=\"text/html; charset=" + encoding + "\" />"
-                     + "\n<title>" + title + "</title>";
+    QString header = QString(
+                         "<!DOCTYPE HTML PUBLIC"
+                         " \"-//W3C//DTD HTML 4.01 //EN\""
+                         " \"http://www.w3.org/TR/html4/strict.dtd\">"
+                         "\n<html>\n<head>"
+                         "\n<meta http-equiv=\"Content-Type\" content=\"text/html; charset=%1\" />"
+                         "\n<title>%2</title>")
+                         .arg(encoding, title);
 
-    QString cssfilename = cssFileNameGet();
+    // inline the CSS
+    header += "<style type=\"text/css\">\n";
+    header += KMyMoneyUtils::getStylesheet(cssFileNameGet());
+    header += "</style>\n";
 
-    if (includeCSS) {
-        // include css inline
-        QFile cssFile(cssfilename);
-        if (cssFile.open(QIODevice::ReadOnly)) {
-            QTextStream cssStream(&cssFile);
-            header += QString("\n<style type=\"text/css\">")
-                      + "\n<!--\n"
-                      + cssStream.readAll()
-                      + "\n-->\n</style>\n";
-            cssFile.close();
-        } else {
-            qDebug() << "reports::ReportTable::htmlHeaderGet: could not open file "
-                     << cssfilename << " readonly";
-        }
-    } else {
-        // do not include css inline instead use a link to the css file
-        header += "\n<link rel=\"stylesheet\" type=\"text/css\" href=\""
-                  + QUrl::fromLocalFile(cssfilename).url() + "\">\n";
-    }
-
-    header += KMyMoneyUtils::variableCSS();
-
-    header += "</head>\n<body>\n";
+    header += QLatin1String("</head>\n<body>\n");
 
     return header;
 }
@@ -105,7 +78,7 @@ QString reports::ReportTable::renderFooter()
     return "</body>\n</html>\n";
 }
 
-QString reports::ReportTable::renderReport(const QString &type, const QByteArray& encoding, const QString &title, bool includeCSS)
+QString reports::ReportTable::renderReport(const QString& type, const QByteArray& encoding, const QString& title)
 {
     MyMoneyFile* file = MyMoneyFile::instance();
     QString result;
@@ -116,7 +89,7 @@ QString reports::ReportTable::renderReport(const QString &type, const QByteArray
 
     if (type == QLatin1String("html")) {
         //this renders the HEAD tag and sets the correct css file
-        result = renderHeader(title, encoding, includeCSS);
+        result = renderHeader(title, encoding);
 
         try {
             // report's name
@@ -124,9 +97,8 @@ QString reports::ReportTable::renderReport(const QString &type, const QByteArray
 
             // report's date range
             result.append(QString::fromLatin1("<div class=\"subtitle\">%1</div>\n"
-                                              "<div class=\"gap\">&nbsp;</div>\n").arg(i18nc("Report date range", "%1 through %2",
-                                                      fromDate.toString(Qt::SystemLocaleShortDate),
-                                                      toDate.toString(Qt::SystemLocaleShortDate))));
+                                              "<div class=\"gap\">&nbsp;</div>\n")
+                              .arg(i18nc("Report date range", "%1 through %2", MyMoneyUtils::formatDate(fromDate), MyMoneyUtils::formatDate(toDate))));
             // report's currency information
             if (m_containsNonBaseCurrency) {
                 result.append(QString::fromLatin1("<div class=\"subtitle\">%1</div>\n"
@@ -150,9 +122,8 @@ QString reports::ReportTable::renderReport(const QString &type, const QByteArray
         result.append(QLatin1String("</body>\n</html>\n"));
     } else if (type == QLatin1String("csv")) {
         result.append(QString::fromLatin1("\"Report: %1\"\n").arg(m_config.name()));
-        result.append(QString::fromLatin1("%1\n").arg(i18nc("Report date range", "%1 through %2",
-                      fromDate.toString(Qt::SystemLocaleShortDate),
-                      toDate.toString(Qt::SystemLocaleShortDate))));
+        result.append(
+            QString::fromLatin1("%1\n").arg(i18nc("Report date range", "%1 through %2", MyMoneyUtils::formatDate(fromDate), MyMoneyUtils::formatDate(toDate))));
         if (m_containsNonBaseCurrency)
             result.append(QString::fromLatin1("%1\n").arg(m_config.isConvertCurrency() ?
                           i18n("All currencies converted to %1", file->baseCurrency().name()) :
