@@ -6,6 +6,7 @@
 
 #include "querytable-test.h"
 
+#include <QBuffer>
 #include <QFile>
 #include <QTest>
 
@@ -24,6 +25,7 @@
 #include "mymoneyutils.h"
 #include "querytable.h"
 #include "tests/testutilities.h"
+#include "xml/mymoneyxmlwriter.h"
 
 using namespace reports;
 using namespace test;
@@ -81,11 +83,38 @@ void writeTabletoXML(const QueryTable& table, const QString& basename = QString(
     g.close();
 }
 
+void writeFile(const QString& basename)
+{
+    MyMoneyFileTransaction ft;
+
+    MyMoneyFile* file = MyMoneyFile::instance();
+
+    // store the user info
+    file->setUser(MyMoneyPayee());
+
+    ft.commit();
+
+    MyMoneyXmlWriter writer;
+    writer.setFile(file);
+    QByteArray data;
+    QBuffer buffer;
+    buffer.setBuffer(&data);
+    buffer.open(QIODevice::WriteOnly);
+    writer.write(&buffer);
+
+    QString filename = QString::fromLatin1("%1/test-%2.xml").arg(CMAKE_CURRENT_BINARY_DIR).arg(basename);
+    QFile g(filename);
+    g.open(QIODevice::WriteOnly);
+    QTextStream(&g) << data;
+    g.close();
+}
+
 void writeTable(const QueryTable& table, const QString& basename = QString())
 {
     writeTabletoCSV(table, basename);
     writeTabletoHTML(table, basename);
     writeTabletoXML(table, basename);
+    writeFile(basename);
 }
 
 void QueryTableTest::init()
@@ -545,35 +574,31 @@ void QueryTableTest::testInvestment()
 
         QList<ListTable::TableRow> rows = invtran.rows();
 
-        QVERIFY(rows.count() == 32);
-        QVERIFY(MyMoneyMoney(rows[1][ListTable::ctValue]) == MyMoneyMoney(-100000.00));
-        QVERIFY(MyMoneyMoney(rows[2][ListTable::ctValue]) == MyMoneyMoney(-110000.00));
-        QVERIFY(MyMoneyMoney(rows[3][ListTable::ctValue]) == MyMoneyMoney(24000.00));
-        QVERIFY(MyMoneyMoney(rows[4][ListTable::ctValue]) == MyMoneyMoney(20000.00));
-        QVERIFY(MyMoneyMoney(rows[5][ListTable::ctValue]) == MyMoneyMoney(5000.00));
-        QVERIFY(MyMoneyMoney(rows[6][ListTable::ctValue]) == MyMoneyMoney(4000.00));
-        QVERIFY(MyMoneyMoney(rows[19][ListTable::ctValue]) == MyMoneyMoney(-50100.00));
-        QVERIFY(MyMoneyMoney(rows[22][ListTable::ctValue]) == MyMoneyMoney(-45100.00));
-        // need to fix these... fundamentally different from the original test
-        //QVERIFY(MyMoneyMoney(invtran.m_rows[8][ListTable::ctValue])==MyMoneyMoney( -1000.00));
-        //QVERIFY(MyMoneyMoney(invtran.m_rows[11][ListTable::ctValue])==MyMoneyMoney( -1200.00));
-        //QVERIFY(MyMoneyMoney(invtran.m_rows[14][ListTable::ctValue])==MyMoneyMoney( -1100.00));
+        QCOMPARE(rows.count(), 32);
+        QCOMPARE(MyMoneyMoney(rows[1][ListTable::ctValue]), MyMoneyMoney(100000.00));
+        QCOMPARE(MyMoneyMoney(rows[2][ListTable::ctValue]), MyMoneyMoney(110000.00));
+        QCOMPARE(MyMoneyMoney(rows[3][ListTable::ctValue]), MyMoneyMoney(-24000.00));
+        QCOMPARE(MyMoneyMoney(rows[4][ListTable::ctValue]), MyMoneyMoney(-20000.00));
+        QCOMPARE(MyMoneyMoney(rows[5][ListTable::ctValue]), MyMoneyMoney(5000.00));
+        QCOMPARE(MyMoneyMoney(rows[6][ListTable::ctValue]), MyMoneyMoney(4000.00));
+        QCOMPARE(MyMoneyMoney(rows[19][ListTable::ctValue]), MyMoneyMoney(50000.00));
+        QCOMPARE(MyMoneyMoney(rows[22][ListTable::ctValue]), MyMoneyMoney(45000.00));
 
-        QVERIFY(MyMoneyMoney(rows[1][ListTable::ctPrice]) == MyMoneyMoney(100.00));
-        QVERIFY(MyMoneyMoney(rows[3][ListTable::ctPrice]) == MyMoneyMoney(120.00));
-        QVERIFY(MyMoneyMoney(rows[5][ListTable::ctPrice]) == MyMoneyMoney(100.00));
-        QVERIFY(MyMoneyMoney(rows[7][ListTable::ctPrice]) == MyMoneyMoney());
-        QVERIFY(MyMoneyMoney(rows[10][ListTable::ctPrice]) == MyMoneyMoney());
-        QVERIFY(MyMoneyMoney(rows[19][ListTable::ctPrice]) == MyMoneyMoney(100.00));
-        QVERIFY(MyMoneyMoney(rows[22][ListTable::ctPrice]) == MyMoneyMoney(90.00));
+        QCOMPARE(MyMoneyMoney(rows[1][ListTable::ctPrice]), MyMoneyMoney(100.00));
+        QCOMPARE(MyMoneyMoney(rows[3][ListTable::ctPrice]), MyMoneyMoney(120.00));
+        QCOMPARE(MyMoneyMoney(rows[5][ListTable::ctPrice]), MyMoneyMoney(100.00));
+        QCOMPARE(MyMoneyMoney(rows[7][ListTable::ctPrice]), MyMoneyMoney());
+        QCOMPARE(MyMoneyMoney(rows[10][ListTable::ctPrice]), MyMoneyMoney());
+        QCOMPARE(MyMoneyMoney(rows[19][ListTable::ctPrice]), MyMoneyMoney(100.00));
+        QCOMPARE(MyMoneyMoney(rows[22][ListTable::ctPrice]), MyMoneyMoney(90.00));
 
-        QVERIFY(MyMoneyMoney(rows[2][ListTable::ctShares]) == MyMoneyMoney(1000.00));
-        QVERIFY(MyMoneyMoney(rows[4][ListTable::ctShares]) == MyMoneyMoney(-200.00));
-        QVERIFY(MyMoneyMoney(rows[6][ListTable::ctShares]) == MyMoneyMoney(50.00));
-        QVERIFY(MyMoneyMoney(rows[8][ListTable::ctShares]) == MyMoneyMoney(0.00));
-        QVERIFY(MyMoneyMoney(rows[11][ListTable::ctShares]) == MyMoneyMoney(0.00));
-        QVERIFY(MyMoneyMoney(rows[19][ListTable::ctShares]) == MyMoneyMoney(500.00));
-        QVERIFY(MyMoneyMoney(rows[22][ListTable::ctShares]) == MyMoneyMoney(500.00));
+        QCOMPARE(MyMoneyMoney(rows[2][ListTable::ctShares]), MyMoneyMoney(1000.00));
+        QCOMPARE(MyMoneyMoney(rows[4][ListTable::ctShares]), MyMoneyMoney(-200.00));
+        QCOMPARE(MyMoneyMoney(rows[6][ListTable::ctShares]), MyMoneyMoney(50.00));
+        QCOMPARE(MyMoneyMoney(rows[8][ListTable::ctShares]), MyMoneyMoney(0.00));
+        QCOMPARE(MyMoneyMoney(rows[11][ListTable::ctShares]), MyMoneyMoney(0.00));
+        QCOMPARE(MyMoneyMoney(rows[19][ListTable::ctShares]), MyMoneyMoney(500.00));
+        QCOMPARE(MyMoneyMoney(rows[22][ListTable::ctShares]), MyMoneyMoney(500.00));
 
         QVERIFY(rows[1][ListTable::ctAction] == "Buy");
         QVERIFY(rows[3][ListTable::ctAction] == "Sell");
@@ -614,10 +639,9 @@ void QueryTableTest::testInvestment()
 #endif
 
 #if 1
-        // i think this is the correct amount. different treatment of dividend and yield
-        QVERIFY(MyMoneyMoney(rows[17][ListTable::ctValue]) == MyMoneyMoney(-153700.00));
-        QVERIFY(MyMoneyMoney(rows[29][ListTable::ctValue]) == MyMoneyMoney(24600.00));
-        QVERIFY(MyMoneyMoney(rows[31][ListTable::ctValue]) == MyMoneyMoney(-129100.00));
+        QVERIFY(MyMoneyMoney(rows[17][ListTable::ctValue]) == MyMoneyMoney(175000.00));
+        QVERIFY(MyMoneyMoney(rows[29][ListTable::ctValue]) == MyMoneyMoney(-25000.00));
+        QVERIFY(MyMoneyMoney(rows[31][ListTable::ctValue]) == MyMoneyMoney(150000.00));
 #else
         QVERIFY(searchHTML(html, i18n("Total Stock 1")) == MyMoneyMoney(171700.00));
         QVERIFY(searchHTML(html, i18n("Grand Total")) == MyMoneyMoney(171700.00));
@@ -644,18 +668,21 @@ void QueryTableTest::testInvestment()
 
         QVERIFY(rows.count() == 5);
         QVERIFY(MyMoneyMoney(rows[0][ListTable::ctExtendedInternalRateOfReturn]) == MyMoneyMoney("669/10000"));
-        QVERIFY(MyMoneyMoney(rows[0][ListTable::ctReturnInvestment]) == MyMoneyMoney("-39/5000"));
+        QVERIFY(MyMoneyMoney(rows[0][ListTable::ctReturn]) == MyMoneyMoney("7300/1"));
+        QVERIFY(MyMoneyMoney(rows[0][ListTable::ctReturnInvestment]) == MyMoneyMoney("87/2500"));
         QVERIFY(MyMoneyMoney(rows[0][ListTable::ctBuys]) == MyMoneyMoney(-210000.00));
         QVERIFY(MyMoneyMoney(rows[0][ListTable::ctSells]) == MyMoneyMoney(44000.00));
         QVERIFY(MyMoneyMoney(rows[0][ListTable::ctReinvestIncome]) == MyMoneyMoney(9000.00));
         QVERIFY(MyMoneyMoney(rows[0][ListTable::ctCashIncome]) == MyMoneyMoney(3300.00));
 
         QVERIFY(MyMoneyMoney(rows[1][ListTable::ctExtendedInternalRateOfReturn]) == MyMoneyMoney("1349/10000"));
+        QVERIFY(MyMoneyMoney(rows[1][ListTable::ctReturn]) == MyMoneyMoney("10000/1"));
         QVERIFY(MyMoneyMoney(rows[1][ListTable::ctReturnInvestment]) == MyMoneyMoney("1/10"));
         QVERIFY(MyMoneyMoney(rows[1][ListTable::ctStartingMarketValue])
                 == MyMoneyMoney(100000.00)); // this should stay non-zero to check if investment performance is calculated at non-zero starting market value
 
         QVERIFY(MyMoneyMoney(rows[2][ListTable::ctExtendedInternalRateOfReturn]) == MyMoneyMoney("2501/2500"));
+        QVERIFY(MyMoneyMoney(rows[2][ListTable::ctReturn]) == MyMoneyMoney("24600/1"));
         QVERIFY(MyMoneyMoney(rows[2][ListTable::ctReturnInvestment]) == MyMoneyMoney("323/1250"));
         QVERIFY(MyMoneyMoney(rows[2][ListTable::ctBuys]) == MyMoneyMoney(-95200.00));
         QVERIFY(MyMoneyMoney(rows[2][ListTable::ctSells]) == MyMoneyMoney(119800.00));
@@ -814,8 +841,12 @@ void QueryTableTest::testBalanceColumn()
         QString openingDate = MyMoneyUtils::formatDate(QDate(2004, 1, 1));
         QString closingDate = MyMoneyUtils::formatDate(QDate(2005, 9, 1));
         QVERIFY(html.indexOf(openingDate + "</td><td class=\"left0\"></td><td class=\"left0\">" + i18n("Opening Balance")) > 0);
-        QVERIFY(html.indexOf(closingDate + "</td><td class=\"left0\"></td><td class=\"left0\">" + i18n("Closing Balance") + "</td><td class=\"left0\"></td><td class=\"value\"></td><td>&nbsp;-702.36</td></tr>") > 0);
-        QVERIFY(html.indexOf(closingDate + "</td><td class=\"left0\"></td><td class=\"left0\">" + i18n("Closing Balance") + "</td><td class=\"left0\"></td><td class=\"value\"></td><td>&nbsp;-705.69</td></tr>") > 0);
+        QVERIFY(html.indexOf(closingDate + "</td><td class=\"left0\"></td><td class=\"left0\">" + i18n("Closing Balance")
+                             + "</td><td class=\"left0\"></td><td>&nbsp;1.0000</td><td class=\"value\"></td><td>&nbsp;-702.36</td></tr>")
+                > 0);
+        QVERIFY(html.indexOf(closingDate + "</td><td class=\"left0\"></td><td class=\"left0\">" + i18n("Closing Balance")
+                             + "</td><td class=\"left0\"></td><td>&nbsp;1.0000</td><td class=\"value\"></td><td>&nbsp;-705.69</td></tr>")
+                > 0);
 
     } catch (const MyMoneyException &e) {
         QFAIL(e.what());
@@ -961,33 +992,44 @@ void QueryTableTest::testBalanceColumnWithMultipleCurrencies()
         QVERIFY(rows.count() == 23);
 
         // check the opening and closing balances
-        QVERIFY(html.indexOf(openingDateString + "</td><td class=\"left0\"></td><td class=\"left0\">" + i18n("Opening Balance") + "</td><td class=\"left0\"></td><td class=\"value\"></td><td>&nbsp;0.00</td></tr>") > 0);
-        QVERIFY(html.indexOf(closingDateString + "</td><td class=\"left0\"></td><td class=\"left0\">" + i18n("Closing Balance") + "</td><td class=\"left0\"></td><td class=\"value\"></td><td>&nbsp;304.00</td></tr>") > 0);
-        QVERIFY(html.indexOf(closingDateString + "</td><td class=\"left0\"></td><td class=\"left0\">" + i18n("Closing Balance") + "</td><td class=\"left0\"></td><td class=\"value\"></td><td>&nbsp;-300.00</td></tr>") > 0);
+        QVERIFY(html.indexOf(openingDateString + "</td><td class=\"left0\"></td><td class=\"left0\">" + i18n("Opening Balance")
+                             + "</td><td class=\"left0\"></td><td>&nbsp;1.0000</td><td class=\"value\"></td><td>&nbsp;0.00</td></tr>")
+                > 0);
+        QVERIFY(html.indexOf(closingDateString + "</td><td class=\"left0\"></td><td class=\"left0\">" + i18n("Closing Balance")
+                             + "</td><td class=\"left0\"></td><td>&nbsp;1.0000</td><td class=\"value\"></td><td>&nbsp;304.00</td></tr>")
+                > 0);
+        QVERIFY(html.indexOf(closingDateString + "</td><td class=\"left0\"></td><td class=\"left0\">" + i18n("Closing Balance")
+                             + "</td><td class=\"left0\"></td><td>&nbsp;1.0000</td><td class=\"value\"></td><td>&nbsp;-300.00</td></tr>")
+                > 0);
         // although the balance should be -5.00 it's -8.00 because the foreign currency balance is converted using the closing date price (0.024)
-        QVERIFY(html.indexOf(closingDateString + "</td><td class=\"left0\"></td><td class=\"left0\">" + i18n("Closing Balance") + "</td><td class=\"left0\"></td><td class=\"value\"></td><td>&nbsp;-8.00</td></tr>") > 0);
+        QVERIFY(html.indexOf(closingDateString + "</td><td class=\"left0\"></td><td class=\"left0\">" + i18n("Closing Balance")
+                             + "</td><td class=\"left0\"></td><td>&nbsp;0.0200</td><td class=\"value\"></td><td>&nbsp;-8.00</td></tr>")
+                > 0);
 
         // a 100.00 JPY transfer should be displayed as -1.00 when converted to the base currency using the opening date price
         QVERIFY(html.indexOf("<a href=\"/ledger?id=A000008&tid=T000000000000000001\">" + openingDateString
-                             + "</a></td><td class=\"left0\"></td><td class=\"left0\">Test Payee</td><td class=\"left0\">Transfer to Checking Account</td><td "
+                             + "</a></td><td class=\"left0\"></td><td class=\"left0\">Test Payee</td><td class=\"left0\">Transfer to Checking "
+                               "Account</td><td>&nbsp;0.0100</td><td "
                                "class=\"value\">&nbsp;-1.00</td><td>&nbsp;-1.00</td></tr>")
                 > 0);
 
         // a 100.00 JPY transfer should be displayed as -1.00 when converted to the base currency using the intermediate date price
         QVERIFY(html.indexOf("<a href=\"/ledger?id=A000008&tid=T000000000000000003\">" + intermediateDateString
-                             + "</a></td><td class=\"left0\"></td><td class=\"left0\">Test Payee</td><td class=\"left0\">Transfer to Checking Account</td><td "
+                             + "</a></td><td class=\"left0\"></td><td class=\"left0\">Test Payee</td><td class=\"left0\">Transfer to Checking "
+                               "Account</td><td>&nbsp;0.0100</td><td "
                                "class=\"value\">&nbsp;-1.00</td><td>&nbsp;-2.00</td></tr>")
                 > 0);
 
         // a 100.00 JPY transfer should be displayed as -2.00 when converted to the base currency using the closing date price (notice the balance is -5.00)
         QVERIFY(html.indexOf("<a href=\"/ledger?id=A000008&tid=T000000000000000005\">" + closingDateString
-                             + "</a></td><td class=\"left0\"></td><td class=\"left0\">Test Payee</td><td class=\"left0\">Transfer to Checking Account</td><td "
+                             + "</a></td><td class=\"left0\"></td><td class=\"left0\">Test Payee</td><td class=\"left0\">Transfer to Checking "
+                               "Account</td><td>&nbsp;0.0200</td><td "
                                "class=\"value\">&nbsp;-2.00</td><td>&nbsp;-5.00</td></tr>")
                 > 0);
 
         // a 100.00 JPY withdrawal should be displayed as -1.00 when converted to the base currency using the intermediate date price
         QVERIFY(html.indexOf("<a href=\"/ledger?id=A000008&tid=T000000000000000007\">" + intermediateDateString
-                             + "</a></td><td class=\"left0\"></td><td class=\"left0\">Test Payee</td><td class=\"left0\">Solo</td><td "
+                             + "</a></td><td class=\"left0\"></td><td class=\"left0\">Test Payee</td><td class=\"left0\">Solo</td><td>&nbsp;0.0100</td><td "
                                "class=\"value\">&nbsp;-1.00</td><td>&nbsp;-3.00</td></tr>")
                 > 0);
 
@@ -1070,20 +1112,48 @@ public:
 
     void testHelperROI()
     {
-        MyMoneyMoney buys(10);
+        MyMoneyMoney buys(-10);
         MyMoneyMoney sells(50);
         MyMoneyMoney reinvestIncome(0);
         MyMoneyMoney cashIncome(70);
         MyMoneyMoney startingBalance(110);
         MyMoneyMoney endingBalance(60);
         QString result1 = helperROI(buys, sells, reinvestIncome, cashIncome, startingBalance, endingBalance);
-        QCOMPARE(result1, MyMoneyMoney(80, 100).convert(10000).toString());
+        QCOMPARE(result1, MyMoneyMoney(1, 2).convert(10000).toString());
 
         buys = MyMoneyMoney(110);
         QString result2 = helperROI(buys, sells, reinvestIncome, cashIncome, startingBalance, endingBalance);
         QCOMPARE(result2, QString());
     }
 
+    // https://bugs.kde.org/show_bug.cgi?id=396301
+    // Dividend paid out
+    void testHelperROI2()
+    {
+        MyMoneyMoney buys(-1200);
+        MyMoneyMoney sells(1000);
+        MyMoneyMoney reinvestedDividend(0);
+        MyMoneyMoney dividendsPaidOut(150);
+        MyMoneyMoney startingBalance(0);
+        MyMoneyMoney endingBalance(200);
+        QString result1 = helperROI(buys, sells, reinvestedDividend, dividendsPaidOut, startingBalance, endingBalance);
+        QCOMPARE(result1, MyMoneyMoney(125, 1000).convert(10000).toString());
+    }
+
+    // https://bugs.kde.org/show_bug.cgi?id=396301
+    // Dividend reinvested
+    void testHelperROI3()
+    {
+        MyMoneyMoney buys(-1200);
+        MyMoneyMoney sells(1000);
+        MyMoneyMoney reinvestedDividend(150);
+        MyMoneyMoney dividendsPaidOut(0);
+        MyMoneyMoney startingBalance(0);
+        MyMoneyMoney endingBalance(350);
+        QString result1 = helperROI(buys, sells, reinvestedDividend, dividendsPaidOut, startingBalance, endingBalance);
+        QCOMPARE(result1, MyMoneyMoney(125, 1000).convert(10000).toString());
+    }
+
     void testHelperXIRR()
     {
         // see https://help.libreoffice.org/latest/de/text/scalc/01/04060118.html
@@ -1114,6 +1184,16 @@ void QueryTableTest::testROI()
     } catch (const MyMoneyException &e) {
         QFAIL(e.what());
     }
+    try {
+        QueryTableProtectedTester().testHelperROI2();
+    } catch (const MyMoneyException& e) {
+        QFAIL(e.what());
+    }
+    try {
+        QueryTableProtectedTester().testHelperROI3();
+    } catch (const MyMoneyException& e) {
+        QFAIL(e.what());
+    }
 }
 
 void QueryTableTest::testXIRR()
