@@ -17,8 +17,11 @@
 // ----------------------------------------------------------------------------
 // Project Includes
 
-#include <kgpgfile.h>
-#include <ui_kgpgkeyselectiondlg.h>
+#include "config-kmymoney.h"
+#include "gpg-recover-key.h"
+#include "kgpgfile.h"
+
+#include "ui_kgpgkeyselectiondlg.h"
 
 class KGpgKeySelectionDlgPrivate
 {
@@ -42,6 +45,7 @@ public:
     bool                      needCheckList;
     bool                      listOk;
     int                       checkCount;
+    QStringList m_recoverKeyList;
 };
 
 
@@ -51,7 +55,15 @@ KGpgKeySelectionDlg::KGpgKeySelectionDlg(QWidget *parent) :
 {
     Q_D(KGpgKeySelectionDlg);
     d->ui->setupUi(this);
-    connect(d->ui->m_secretKey, SIGNAL(currentIndexChanged(int)), this, SLOT(slotIdChanged()));
+
+    d->m_recoverKeyList = QStringLiteral(OLD_RECOVER_KEY_IDS).split(':');
+    d->m_recoverKeyList.append(RECOVER_KEY_ID);
+
+    for (auto it = d->m_recoverKeyList.begin(); it != d->m_recoverKeyList.end(); ++it) {
+        *it = (*it).replace(QLatin1String("0x"), QString());
+    }
+
+    connect(d->ui->m_secretKey, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &KGpgKeySelectionDlg::slotIdChanged);
     connect(d->ui->m_listWidget, &KEditListWidget::changed, this, &KGpgKeySelectionDlg::slotIdChanged);
     connect(d->ui->m_listWidget, &KEditListWidget::added, this, &KGpgKeySelectionDlg::slotKeyListChanged);
     connect(d->ui->m_listWidget, &KEditListWidget::removed, this, &KGpgKeySelectionDlg::slotKeyListChanged);
@@ -65,20 +77,24 @@ KGpgKeySelectionDlg::~KGpgKeySelectionDlg()
 
 void KGpgKeySelectionDlg::setSecretKeys(const QStringList& keyList, const QString& defaultKey)
 {
-    static constexpr char recoveryKeyId[] = "59B0F826D2B08440";
-
     Q_D(KGpgKeySelectionDlg);
     d->ui->m_secretKey->addItem(i18n("No encryption"));
 
-    foreach(auto key, keyList) {
-        QStringList fields = key.split(':', QString::SkipEmptyParts);
-        if (fields[0] != recoveryKeyId) {
+    // load m_secretKey with available private keys
+    // but don't show the recover keys and omit duplicate
+    // addresses for the same key id
+    QStringList loadedKeys;
+    for (const auto& key : keyList) {
+        QStringList fields = key.split(':', Qt::SkipEmptyParts);
+        const auto keyId = fields[0];
+        if (!d->m_recoverKeyList.contains(keyId) && !loadedKeys.contains(keyId)) {
             // replace parenthesis in name field with brackets
             auto name = fields[1];
             name.replace('(', "[");
             name.replace(')', "]");
-            name = QString("%1 (0x%2)").arg(name).arg(fields[0]);
+            name = QString("%1 (0x%2)").arg(name, fields[0]);
             d->ui->m_secretKey->addItem(name);
+            loadedKeys.append(keyId);
             if (name.contains(defaultKey)) {
                 d->ui->m_secretKey->setCurrentText(name);
             }
@@ -131,6 +147,7 @@ void KGpgKeySelectionDlg::slotKeyListChanged()
 
 void KGpgKeySelectionDlg::slotIdChanged()
 {
+#ifdef ENABLE_GPG
     Q_D(KGpgKeySelectionDlg);
     // this looks a bit awkward. Here's why: KGPGFile::keyAvailable() starts
     // an external task and processes UI events while it waits for the external
@@ -157,7 +174,7 @@ void KGpgKeySelectionDlg::slotIdChanged()
                 if (d->needCheckList) {
                     QStringList keys = d->ui->m_listWidget->items();
                     QStringList::const_iterator it_s;
-                    for (it_s = keys.constBegin(); keysOk && it_s != keys.constEnd(); ++it_s) {
+                    for (it_s = keys.cbegin(); keysOk && it_s != keys.cend(); ++it_s) {
                         if (!KGPGFile::keyAvailable(*it_s))
                             keysOk = false;
                     }
@@ -186,4 +203,5 @@ void KGpgKeySelectionDlg::slotIdChanged()
         --d->checkCount;
         d->ui->buttonBox->button(QDialogButtonBox::Ok)->setEnabled(!enabled || (d->ui->m_keyLed->state() == KLed::On));
     }
+#endif
 }
