@@ -1169,6 +1169,8 @@ void InvestTransactionEditor::loadTransaction(const QModelIndex& index)
         d->protectWidgetsForClosedAccount();
 
         updateTotalAmount();
+
+        d->currentActivity->consistencyCheck();
     }
 
     d->bypassUserPriceUpdate = false;
@@ -1278,6 +1280,8 @@ QStringList InvestTransactionEditor::saveTransaction(const QStringList& selected
 {
     MyMoneyTransaction t;
 
+    updateTotalAmount();
+
     auto selection(selectedJournalEntries);
     connect(MyMoneyFile::instance()->journalModel(), &JournalModel::idChanged, this, [&](const QString& currentId, const QString& previousId) {
         selection.replaceInStrings(previousId, currentId);
