@@ -486,7 +486,7 @@ public:
         journalDelegate->setProperty("transactionMatchedColor", KMyMoneySettings::schemeColor(SchemeColor::TransactionMatched));
         journalDelegate->setProperty("transactionMatchedText", KMyMoneySettings::schemeColor(SchemeColor::TransactionMatchedText));
 
-        journalDelegate->setProperty("erroneousText", KMyMoneySettings::schemeColor(SchemeColor::TransactionErroneous));
+        journalDelegate->setProperty("transactionErroneousColor", KMyMoneySettings::schemeColor(SchemeColor::TransactionErroneous));
     }
 
     void allowSectionResize()
@@ -829,6 +829,7 @@ void LedgerView::closeEditor(QWidget* editor, QAbstractItemDelegate::EndEditHint
 
     d->editIndex = QModelIndex();
     QMetaObject::invokeMethod(this, &LedgerView::ensureCurrentItemIsVisible, Qt::QueuedConnection);
+    QMetaObject::invokeMethod(this, &LedgerView::setFocus, Qt::QueuedConnection);
 }
 
 QModelIndex LedgerView::editIndex() const
@@ -1314,7 +1315,27 @@ void LedgerView::adjustDetailColumn(int newViewportWidth, bool informOtherViews)
 
 void LedgerView::ensureCurrentItemIsVisible()
 {
-    scrollTo(currentIndex(), EnsureVisible);
+    // make sure scrollTo has an effect which is only the case
+    // when the QModelIndex points to a visible cell.
+    const auto idx = currentIndex();
+    if (idx.isValid()) {
+        const auto column = horizontalHeader()->logicalIndexAt(0);
+        const auto parentIdx = idx.parent();
+        auto row = idx.row();
+
+        // if it's not the first transaction, we scroll to the one before
+        if (row > 0) {
+            --row;
+        }
+        scrollTo(idx.model()->index(row, column, parentIdx), EnsureVisible);
+
+        row = idx.row();
+        // if it's not the last transaction, we scroll to the one after
+        if (row + 1 < idx.model()->rowCount(parentIdx)) {
+            ++row;
+        }
+        scrollTo(idx.model()->index(row, column, parentIdx), EnsureVisible);
+    }
 }
 
 void LedgerView::slotSettingsChanged()
