@@ -49,7 +49,7 @@ Q_GLOBAL_STATIC(AmountEditHelper, s_globalAmountEdit)
 AmountEdit* AmountEdit::global()
 {
     if (!s_globalAmountEdit()->q) {
-        s_globalAmountEdit()->q = new AmountEdit(0, 2);
+        s_globalAmountEdit()->q = new AmountEdit(nullptr, 2);
     }
 
     return s_globalAmountEdit()->q;
@@ -79,6 +79,7 @@ public:
         , m_precisionOverridesFraction(false)
         , m_isReadOnly(false)
         , m_allowModifyShares(true)
+        , m_isEnabled(qq->isEnabled())
         , m_actionIcons(NoItem)
         , m_initialExchangeRate(MyMoneyMoney::ONE)
         , m_state(AmountEdit::DisplayValue)
@@ -121,6 +122,7 @@ public:
         m_currencyButton->setAutoRaise(true);
         m_currencyButton->hide();
         m_currencyButton->setFocusPolicy(Qt::ClickFocus);
+        m_currencyButton->setFont(q->font());
 
         // setup items
         KSharedConfig::Ptr kconfig = KSharedConfig::openConfig();
@@ -185,8 +187,21 @@ public:
         m_calculatorButton->move(q->width() - m_calculatorButton->width() - frameWidth, btnX);
         widget->move(q->width() - m_calculatorButton->width() - widget->width() - gaps * frameWidth, currencyX);
 
+        // It was reported in https://bugs.kde.org/show_bug.cgi?id=497255 that
+        // changing the font of the ledger cells updates all widgets in the
+        // transaction editors except the amount widgets. While investigating
+        // the problem, it has been noticed, that when setting the style sheet
+        // a second time, a previously modified font size gets reset to the system
+        // size. So in case we are about to change the stylesheet, we keep a copy
+        // of the font and set it back to that copy after changing the stylesheet.
+        //
+        // The observed behavior may have something to do with the default setting of
+        // Qt::AA_UseStyleSheetPropagationInWidgetStyles.
         const int padding = m_calculatorButton->width() + widget->width() + ((gaps - 1) * frameWidth);
-        q->setStyleSheet(QString("QLineEdit { padding-right: %1px }").arg(padding));
+        const auto font(q->font());
+        q->setStyleSheet(QStringLiteral("QLineEdit { padding-right: %1px }").arg(padding));
+        // avoid infinite recursive calls here
+        q->QLineEdit::setFont(font);
         q->setMinimumHeight(height);
     }
 
@@ -309,8 +324,9 @@ public:
     void setWidgetText(QString& widgetTextCache, const MyMoneyMoney& amount, const QString& txt, MultiCurrencyEdit::DisplayState state)
     {
         Q_Q(AmountEdit);
+        bool enabled = false;
         if (!amount.isAutoCalc()) {
-            q->setEnabled(true);
+            enabled = m_isEnabled;
             widgetTextCache = txt;
             if (q->isEnabled() && !txt.isEmpty()) {
                 ensureFractionalPart(widgetTextCache, state);
@@ -322,10 +338,11 @@ public:
                 q->QLineEdit::setText(widgetTextCache);
             }
         } else {
-            q->setEnabled(false);
             QSignalBlocker block(q);
             q->QLineEdit::setText(i18nc("@info:placeholder amount widget", "calculated"));
         }
+        // use the base class version to keep m_isEnabled as it is
+        q->QLineEdit::setEnabled(enabled);
     }
 
     void setValueText(const QString& txt)
@@ -355,6 +372,7 @@ public:
     bool m_precisionOverridesFraction;
     bool m_isReadOnly; // read only state as set by application
     bool m_allowModifyShares; // allow to override shares even if read only state
+    bool m_isEnabled;
     QString m_previousText; // keep track of what has been typed
 
     QString m_valueText; // keep track of what was the original value
@@ -728,13 +746,13 @@ void AmountEdit::theTextChanged(const QString & theText)
 void AmountEdit::slotCalculatorOpen()
 {
     Q_D(AmountEdit);
-    d->calculatorOpen(0);
+    d->calculatorOpen(nullptr);
 }
 
 void AmountEdit::slotCalculatorClose()
 {
     Q_D(AmountEdit);
-    if (d->m_calculator != 0) {
+    if (d->m_calculator != nullptr) {
         d->m_calculatorFrame->hide();
     }
 }
@@ -761,7 +779,7 @@ void AmountEdit::slotCalculatorResult()
 {
     Q_D(AmountEdit);
     slotCalculatorClose();
-    if (d->m_calculator != 0) {
+    if (d->m_calculator != nullptr) {
         MyMoneyMoney amount(d->m_calculator->result());
         amount = d->adjustToPrecision(d->m_state, amount);
         setText(amount.formatMoney(QString(), d->precision(d->m_state), false));
@@ -929,3 +947,17 @@ void AmountEdit::setAllowModifyShares(bool allowModifyShares)
         d->setReadOnly(!allowModifyShares);
     }
 }
+
+void AmountEdit::setFont(const QFont& font)
+{
+    Q_D(AmountEdit);
+    QLineEdit::setFont(font);
+    d->updateLineEditSize(d->m_calculatorButton);
+}
+
+void AmountEdit::setEnabled(bool enable)
+{
+    Q_D(AmountEdit);
+    d->m_isEnabled = enable;
+    QLineEdit::setEnabled(enable);
+}
